<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:hiko="http://www.historischekommission-muenchen.de" xmlns:my="http://zeromat.org" version="2.0">


    <!--Kein Indent wegen Leerzeichen -->
    <xsl:output method="xml" version="1.0" indent="no"/>
    <xsl:preserve-space elements="*"/>

    <!-- - - - - - - - - - -    PARAMETER   - - - - - - - - - - -->
    <xsl:param name="PER" select="''"/>
    <xsl:variable name="per" select="document($PER)"/>
    <xsl:variable name="per_path" select="$PER"/>
    <xsl:param name="EDITION_PATH" select="''"/>
    <xsl:variable name="edition_path" select="$EDITION_PATH"/>

    <!-- - - - - - - - - - -    SCHRIFTARTEN    - - - - - - - - - - -->
    <xsl:variable name="ftSf" select="'AGaramondPHK-Regular'"/>
    <xsl:variable name="ftSfObl" select="'AGaramondPHK-Italic'"/>
    <xsl:variable name="ftSfBd" select="'AGaramondPHK-Bold'"/>
    <xsl:variable name="ftSFBdObl" select="'AGaramondPHK-BoldItalic'"/>
    <xsl:variable name="arialUC" select="'ARIALUNI'"/>

    <!-- - - - - - - - - - -    SCHRIFTGRÖßEN   - - - - - - - - - - -->
    <xsl:variable name="ftsz_Fließtext" select="'11pt'"/>
    <xsl:variable name="ftsz_Protokollkopf" select="'14pt'"/>
    <xsl:variable name="ftsz_Überschrift_Abschnitt" select="'14pt'"/>

    <xsl:variable name="ftsz_Kopfzeile" select="'10pt'"/>
    <xsl:variable name="ftsz_Seitenzahl" select="'10pt'"/>

    <xsl:variable name="ftsz_Fußnoten" select="'9pt'"/>
    <xsl:variable name="ftsz_Fußnziffer_Text" select="'10pt'"/>
    <xsl:variable name="ftsz_Fußnziffer_Apparat" select="'6pt'"/>

    <xsl:variable name="ftsz_Erläuterungstext" select="'9pt'"/>
    <xsl:variable name="ftsz_PTVZTO" select="'10pt'"/>
    <xsl:variable name="ftsz_einspaltRegister" select="'10pt'"/>
    <xsl:variable name="ftsz_zweispaltRegister" select="'9pt'"/>


    <!-- - - - - - - - - -  STATISCHE VARIABLEN - - - - - - - - - - -->

    <!-- DokumentenID -->
    <xsl:variable name="currentDocID">
        <xsl:value-of select="/tei:TEI/@xml:id"/>
    </xsl:variable>

    <!--Statische Variablen für Anmerkungsreferenzen -->
    <xsl:variable name="ehr33_refText">
        <fo:inline font-family="{$ftSfObl}">Protokolle Ehard</fo:inline>
        <fo:inline font-family="{$ftSf}"> III Bd. 3</fo:inline>
    </xsl:variable>

    <xsl:variable name="ehr34_refText">
        <fo:inline font-family="{$ftSfObl}">Protokolle Ehard</fo:inline>
        <fo:inline font-family="{$ftSf}"> III Bd. 4</fo:inline>
    </xsl:variable>
    
    <xsl:variable name="hoe21_refText">
        <fo:inline font-family="{$ftSfObl}">Protokolle Hoegner</fo:inline>
        <fo:inline font-family="{$ftSf}"> II Bd. 1</fo:inline>
    </xsl:variable>

    <xsl:variable name="ehr33_path" select="'/edition-ehr33'"/>
    <xsl:variable name="ehr34_path" select="'/edition-ehr34'"/>
    <xsl:variable name="hoe21_path" select="'/edition-hoe21'"/>

    <xsl:variable name="protokoll_path" select="'/Protokolle'"/>
    <xsl:variable name="abschnitt_path" select="'/Editionsabschnitte'"/>


    <!-- - - - - - - - - - -    BASIS   - - - - - - - - - - -->
    <xsl:template match="/">
        <fo:root font-size="{$ftsz_Fließtext}" font-family="{$ftSf}" line-height="115%" xml:lang="de" language="de" hyphenate="true" line-height-shift-adjustment="disregard-shifts" hyphenation-push-character-count="4" hyphenation-remain-character-count="4" overflow="error-if-overflow">

            <!--Seite einrichten-->
            <fo:layout-master-set>
                <fo:simple-page-master master-name="standart-seite" page-height="297mm" page-width="210mm" margin="20mm">
                    <fo:region-body margin-top=".5in" margin-bottom="0.7in"/>
                    <fo:region-before extent=".5in" region-name="xsl-region-before"/>
                </fo:simple-page-master>
            </fo:layout-master-set>

            <fo:page-sequence master-reference="standart-seite">

                <!--Kopfzeile-->
                <fo:static-content flow-name="xsl-region-before">
                    <fo:table table-layout="fixed" width="170mm" space-before="0" space-after="0" border-bottom="1px solid black" color="#336699">
                        <fo:table-column column-width="20mm" text-align="left"/>
                        <fo:table-column column-width="130mm" text-align="center"/>
                        <fo:table-column column-width="20mm" text-align="end"/>
                        <fo:table-body>
                            <fo:table-row>
                                <fo:table-cell>
                                    <fo:block>
                                        <xsl:text>Nr. </xsl:text>
                                        <xsl:value-of select="//tei:title[@type = 'Protokoll']"/>
                                    </fo:block>
                                </fo:table-cell>
                                <fo:table-cell text-align="center">
                                    <fo:block>
                                        <xsl:value-of select="my:replMonth(format-date(//tei:div[@type = 'Dokumentenkopf']//tei:head[1]//tei:date[1]/@when, '[D1]. [MNn] [Y0001]'))"/>
                                    </fo:block>
                                </fo:table-cell>
                                <fo:table-cell>
                                    <fo:block font-size="{$ftsz_Seitenzahl}" text-align="right">
                                        <fo:page-number/>
                                    </fo:block>
                                </fo:table-cell>
                            </fo:table-row>
                        </fo:table-body>
                    </fo:table>
                </fo:static-content>

                <!--Hauptteil-->
                <fo:flow flow-name="xsl-region-body">
                    <xsl:apply-templates select="//tei:text"/>
                </fo:flow>

            </fo:page-sequence>
        </fo:root>
    </xsl:template>


    <!-- - - - - - - - - - -    PROTOKOLLKOPF   - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Dokumentenkopf']">

        <!--Protokollnummer-->
        <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Protokollkopf}" space-after="3.5mm" text-align="center" role="H1">
            <xsl:apply-templates select="tei:head/tei:num"/>
        </fo:block>

        <fo:table table-layout="fixed" width="170mm" space-before="1.75mm" space-after="3.5mm" border-collapse="separate" border-spacing="1.75mm 0.7mm">
            <fo:table-column column-width="82mm"/>
            <fo:table-column column-width="5mm"/>
            <fo:table-column column-width="82mm"/>


            <fo:table-body>
                <!--Protokolltitel & Datum -->
                <fo:table-row>
                    <fo:table-cell>
                        <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Protokollkopf}" space-before="1mm" space-after="3.5mm">
                            <xsl:apply-templates select="tei:head/tei:seg"/>
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell>
                        <fo:block/>
                    </fo:table-cell>
                    <fo:table-cell text-align="right">
                        <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Protokollkopf}" space-before="1mm" space-after="3.5mm">
                            <xsl:apply-templates select="tei:head/tei:date" mode="ohnezeit"/>
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>

                <!--Beginn- & Endzeitpunkt-->
                <fo:table-row>
                    <fo:table-cell>
                        <fo:block>Beginn: <xsl:value-of select="tei:head//tei:time[@type = 'Beginn']"/>
                        </fo:block>
                    </fo:table-cell>

                    <fo:table-cell>
                        <fo:block/>
                    </fo:table-cell>

                    <fo:table-cell text-align="right">
                        <fo:block>Ende: <xsl:value-of select="tei:head//tei:time[@type = 'Ende']"/>
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>

            </fo:table-body>
        </fo:table>

        <xsl:apply-templates select="tei:div"/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Dokumentenkopf']/tei:head/tei:num">
        <xsl:apply-templates/>
    </xsl:template>

    <!--Unter-divs des Protokollkopfs-->
    <xsl:template match="tei:div[matches(@type, '(Anwesend|Entschuldigt|Tagesordnung)')]">
        <fo:block space-after="1em" text-align="justify">
            <fo:inline font-family="{$ftSfObl}">
                <xsl:value-of select="@type"/>
                <xsl:text>:</xsl:text>
            </fo:inline>
            <xsl:apply-templates mode="dokumentenkopf"/>
        </fo:block>
    </xsl:template>


    <!-- - - - - - - - - - -    GRUßWORTE   - - - - - - - - - - -->
    <xsl:template match="tei:closer">
        <fo:table table-layout="fixed" width="170mm" space-before="3.5mm" space-after="1mm" border-collapse="separate" border-spacing="1.75mm 4mm" color="#336699" page-break-inside="avoid">
            <fo:table-column column-width="88mm"/>
            <fo:table-column column-width="4mm"/>
            <fo:table-column column-width="88mm"/>

            <fo:table-body>
                <xsl:choose>

                    <!--Vier Grußworte: Layout =    o x
                                                    x x
                                                    x o
                    -->
                    <xsl:when test="count(tei:seg) = 4">
                        <fo:table-row>
                            <fo:table-cell text-align="center">
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[1]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>

                        <fo:table-row>
                            <fo:table-cell text-align="center" padding-top="1em" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[2]"/>
                                </fo:block>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center" padding-top="1em" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[3]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>

                        <fo:table-row>
                            <fo:table-cell text-align="center" padding-top="1em" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[4]"/>
                                </fo:block>
                            </fo:table-cell>


                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>


                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>
                        </fo:table-row>


                    </xsl:when>

                    <!--Drei Grußworte: Layout =    o x
                                                    x x
                    -->
                    <xsl:when test="count(tei:seg) = 3">
                        <fo:table-row>
                            <fo:table-cell text-align="center">
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[1]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>

                        <fo:table-row>
                            <fo:table-cell text-align="center" padding-top="1em" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[2]"/>
                                </fo:block>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center" padding-top="1em" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[3]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:when>

                    <!--Zwei Grußworte: Layout =  x x -->
                    <xsl:when test="count(tei:seg) = 2">
                        <fo:table-row>
                            <fo:table-cell text-align="center" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[1]"/>
                                </fo:block>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[2]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:when>

                    <!-- Ein Grußwort: Layout = o x -->
                    <xsl:when test="count(tei:seg) = 1">
                        <fo:table-row>
                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center" hyphenate="false">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[1]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:when>
                </xsl:choose>
            </fo:table-body>
        </fo:table>
    </xsl:template>

    <xsl:template match="tei:seg[@type = 'Grußwort']">
        <xsl:apply-templates/>
    </xsl:template>

    <!--Grußworts-Teile-->
    <xsl:template match="tei:seg[ancestor::tei:seg[@type = 'Grusswort']]">
        <fo:block hyphenate="false">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>


    <!-- - - - - - - - - - -    FUßNOTEN    - - - - - - - - - - -->
    <xsl:template match="tei:note">
        <xsl:variable name="footnoteNumber">
            <xsl:choose>
                <xsl:when test="@n">
                    <xsl:value-of select="@n"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="count(preceding::tei:note) + 1"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:footnote page-break-after="auto" page-break-inside="auto">
            <fo:inline font-size="{$ftsz_Fußnziffer_Text}" baseline-shift="super" font-family="{$ftSf}">
                <xsl:value-of select="$footnoteNumber"/>
            </fo:inline>
            <fo:footnote-body font-size="{$ftsz_Fußnoten}" font-family="{$ftSf}" color="black" text-indent="0" line-height="110%" text-align="justify" page-break-after="auto" page-break-inside="auto">
                <fo:list-block provisional-distance-between-starts="4mm">
                    <fo:list-item>
                        <fo:list-item-label end-indent="label-end()">
                            <fo:block font-size="{$ftsz_Fußnziffer_Apparat}" baseline-shift="super">
                                <xsl:value-of select="$footnoteNumber"/>
                            </fo:block>
                        </fo:list-item-label>
                        <fo:list-item-body start-indent="body-start()">
                            <fo:block>
                                <xsl:apply-templates/>
                            </fo:block>
                        </fo:list-item-body>
                    </fo:list-item>
                </fo:list-block>
            </fo:footnote-body>
        </fo:footnote>
    </xsl:template>

    <!--Zweite Version für Datumszeile-->
    <xsl:template match="tei:note" mode="ohnezeit">
        <xsl:variable name="footnoteNumber">
            <xsl:choose>
                <xsl:when test="@n">
                    <xsl:value-of select="@n"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="count(preceding::tei:note) + 1"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:footnote>
            <fo:inline font-size="{$ftsz_Fußnziffer_Text}" baseline-shift="super">
                <xsl:value-of select="$footnoteNumber"/>
            </fo:inline>
            <fo:footnote-body font-size="{$ftsz_Fußnoten}" font-family="{$ftSf}" color="black" text-indent="0" line-height="110%" text-align="justify">
                <fo:list-block provisional-distance-between-starts="4mm">
                    <fo:list-item>
                        <fo:list-item-label end-indent="label-end()">
                            <fo:block font-size="{$ftsz_Fußnziffer_Apparat}" baseline-shift="super" line-height="110%">
                                <xsl:value-of select="$footnoteNumber"/>
                            </fo:block>
                        </fo:list-item-label>
                        <fo:list-item-body start-indent="body-start()">
                            <fo:block>
                                <xsl:apply-templates/>
                            </fo:block>
                        </fo:list-item-body>
                    </fo:list-item>
                </fo:list-block>
            </fo:footnote-body>
        </fo:footnote>
    </xsl:template>


    <!-- - - - - - - - - - -    TABELLEN    - - - - - - - - - - -->
    <xsl:template match="tei:table">

        <fo:table space-before="0.5em" space-after="0.5em">
            <fo:table-body>
                <xsl:apply-templates select="tei:row"/>
            </fo:table-body>
        </fo:table>
    </xsl:template>

    <xsl:template match="tei:row">
        <fo:table-row>
            <xsl:apply-templates/>
        </fo:table-row>

    </xsl:template>

    <xsl:template match="tei:cell">

        <xsl:variable name="alignment">
            <xsl:choose>
                <xsl:when test="@rend">
                    <xsl:choose>
                        <xsl:when test="@rend = 'aligncenter'">
                            <xsl:text>center</xsl:text>
                        </xsl:when>
                        <xsl:when test="@rend = 'alignright'">
                            <xsl:text>end</xsl:text>
                        </xsl:when>
                    </xsl:choose>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>start</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:table-cell border="0px" text-align="{$alignment}" display-align="after" padding="0.3em">
            <fo:block>
                <xsl:apply-templates/>
            </fo:block>
        </fo:table-cell>
    </xsl:template>


    <!-- - - - - - - - - - -    TOP/UNTERPUNKT-ÜBERSCHRIFTEN   - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Top']/tei:head">
        <xsl:variable name="pba">
            <xsl:choose>
                <xsl:when test="../@rend = 'headbreak'">
                    <xsl:value-of select="'auto'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'avoid'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="space-before">
            <xsl:choose>
                <xsl:when test="../@rend = 'nospacebefore'">
                    <xsl:value-of select="'0'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'2mm'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>


        <fo:block font-family="{$ftSfObl}" space-before="{$space-before}" space-after="1mm" page-break-after="{$pba}" page-break-inside="avoid" text-align="justify" line-height="115%" linefeed-treatment="ignore">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <!-- Unterpunkts-Überschriften -->
    <xsl:template match="tei:div[@type = 'Unterpunkt']/tei:head">
        <fo:block text-align="justify">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <!--Leerzeichen zwischen Top-Nummer und Überschrift einfügen-->
    <xsl:template match="tei:div[@type = 'Top' or @type = 'Unterpunkt']/tei:head/tei:num">
        <fo:inline>
            <xsl:apply-templates/>
            <xsl:text>&#160;</xsl:text>
        </fo:inline>
    </xsl:template>

    <!-- Kein Leerzeichen nach der Topnummer, wenn nur die Top-Nummer eingefügt wurde -->
    <xsl:template match="tei:div[@type = 'Top' or @type = 'Unterpunkt']/tei:head/tei:add/tei:num">
        <fo:inline>
            <xsl:apply-templates/>
        </fo:inline>
        <xsl:choose>
            <xsl:when test="./parent::tei:add[./text()]">
                <xsl:text>&#160;</xsl:text>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Schattenunterpunkt']/tei:head"/>


    <!-- - - - - - - - - - -     TOP-/UNTERPUNKTINHALT  - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Top'] | tei:div[@type = 'Unterpunkt'] | tei:div[@type = 'Schattenunterpunkt']">
        <xsl:apply-templates/>
    </xsl:template>


    <!-- - - - - - - - - - -    ANLAGEN - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Anlage']">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Anlagenkopf']">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Anlagenkopf']/tei:head">
        <!--Nummer-->
        <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Protokollkopf}" space-after="3.5mm" text-align="center">
            <xsl:apply-templates select="./tei:num"/>
        </fo:block>

        <fo:table table-layout="fixed" width="170mm" space-before="1.75mm" space-after="3.5mm" border-collapse="seperate" border-spacing="1.75mm 0.75mm">
            <fo:table-column column-width="82mm"/>
            <fo:table-column column-width="5mm"/>
            <fo:table-column column-width="82mm"/>


            <fo:table-body>
                <!--Protokolltitel & Datum -->
                <fo:table-row>
                    <fo:table-cell>
                        <fo:block font-family="{$ftSf}" font-size="{$ftsz_Protokollkopf}" space-before="1mm" space-after="3.5mm">
                            <xsl:apply-templates select="./tei:seg"/>
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell>
                        <fo:block/>
                    </fo:table-cell>
                    <fo:table-cell text-align="right">
                        <fo:block font-family="{$ftSf}" font-size="{$ftsz_Protokollkopf}" space-before="1mm" space-after="3.5mm">
                            <xsl:apply-templates select="./tei:date"/>
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>

            </fo:table-body>
        </fo:table>
    </xsl:template>


    <xsl:template match="tei:div[@type = 'Anlagenkopf']/tei:head/tei:num">
        <fo:block font-family="{$ftSf}" font-size="{$ftsz_Überschrift_Abschnitt}" space-before="1mm" space-after="3.5mm"/>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Anlagenkopf']/tei:head/tei:seg">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Anlagenkopf']/tei:head/tei:date">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Anlagentext']">
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="tei:div[@type = 'Anlagentext']/tei:head">

        <fo:block font-family="{$ftSf}" font-size="{$ftsz_Überschrift_Abschnitt}" space-before="1mm" space-after="3.5mm" text-align="center">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Anlage']/tei:head">
        <fo:block font-family="{$ftSfObl}" space-before="3.5mm" space-after="1mm" text-align="center">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>


    <!-- - - - - - - - - - -    TEXTABSCHNITTE  - - - - - - - - - - -->

    <!-- Abschnittüberschriften -->
    <xsl:template match="tei:body/tei:head">
        <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Überschrift_Abschnitt}" text-align="center" line-height="1em" margin-bottom="1.5em" page-break-after="avoid">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Unterabschnitt']">
        <fo:block id="{generate-id()}">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Unterabschnitt']/tei:head">
        <fo:block text-align="center" space-before="6mm" space-after="3mm" font-size="{$ftsz_Überschrift_Abschnitt}" line-height="125%" page-break-after="avoid">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Textunterpunkt']">
        <fo:block id="{generate-id()}">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Textunterpunkt']/tei:head">
        <fo:block text-align="center" space-before="5mm" space-after="2mm" font-family="{$ftSfObl}">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <!--Leerzeichen zwischen Unterabschnitt und Textunterpunkt einfügen-->
    <xsl:template match="tei:div[@type = 'Unterabschnitt' or @type = 'Textunterpunkt']/tei:head/tei:num">
        <fo:inline>
            <xsl:apply-templates/>
            <xsl:text>&#160;</xsl:text>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Textteilpunkt']">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Erläuterungstext']">
        <fo:block margin-bottom="6mm" font-size="{$ftsz_Erläuterungstext}">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>


    <!-- - - - - - - - - - -    ABSÄTZE   - - - - - - - - - - -->
    <xsl:template match="tei:p">

        <!--Spezielle Ausrichtung -->
        <xsl:choose>
            <xsl:when test=".[@rend = 'aligncenter' or @rend = 'alignright']">
                <xsl:variable name="alignment">
                    <xsl:choose>
                        <xsl:when test="@rend">
                            <xsl:choose>
                                <xsl:when test="@rend = 'aligncenter'">
                                    <xsl:value-of select="'center'"/>
                                </xsl:when>
                                <xsl:when test="@rend = 'alignright'">
                                    <xsl:value-of select="'end'"/>
                                </xsl:when>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="'justify'"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>

                <fo:block text-align="{$alignment}" line-height="115%" role="P">
                    <xsl:apply-templates/>
                </fo:block>
            </xsl:when>
            
            <!-- Druckregister -->
            <xsl:when test="./@rend = 'head'">
                <fo:block font-family="{$ftSfBd}" font-size="14pt" text-align="center" margin-top="2em" margin-bottom="1em" text-decoration="underline">
                    <xsl:apply-templates/>
                </fo:block>
            </xsl:when>
            <xsl:when test="./@rend = 'vortext'">
                <fo:block font-family="{$ftSf}" font-size="10pt" text-align="justify" margin-bottom="1em">
                    <xsl:apply-templates/>
                </fo:block>
            </xsl:when>                       

            <!-- Normaler Blocksatz mit Einzug in erster Zeile -->
            <xsl:otherwise>
                <!--Bei erstem Absatz keinen Einzug wenn in Tagesordnungspunkt, Textabschnitt oder Erläuterungstext oder wenn speziell markiert-->
                <xsl:choose>
                    <xsl:when test="./@rend = 'standalone'">
                        <fo:block text-align="justify" line-height="115%">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:when>
                    <xsl:when test=".[parent::tei:div[@type = 'Top' or @type = 'Textteilpunkt' or @type = 'Erläuterungstext' or @type = 'Freiblock'] and not(preceding-sibling::tei:p)]">
                        <fo:block text-align="justify" line-height="115%">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:when>
                    <xsl:otherwise>
                        <fo:block text-align="justify" text-indent="3mm" line-height="115%">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="tei:p" mode="dokumentenkopf">
        <fo:inline>
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>


    <!-- - - - - - - - - - -    TEXTELEMENTE   - - - - - - - - - - -->

    <!--Markierte Änderungen  -->
    <xsl:template match="tei:add">
        <!-- Bei Änderungen in Tagesordnungsüberschriften die eckigen Klammern nicht kursiviert setzen -->
        <xsl:choose>
            <xsl:when test="./ancestor::tei:div[@type = 'Top']">
                <fo:inline font-family="{$ftSf}">[</fo:inline>
                <xsl:apply-templates/>
                <fo:inline font-family="{$ftSf}">]</fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline>[</fo:inline>
                <xsl:apply-templates/>
                <fo:inline>]</fo:inline>
            </xsl:otherwise>
        </xsl:choose>

        <!-- Wenn Änderung (nur) eine Top-Nummer betrifft - dahinter ein Leerzeichen einfügen-->
        <xsl:choose>
            <xsl:when test=".[parent::tei:head[parent::tei:div[@type = 'Top' or @type = 'Unterpunkt']] and not(child::text())]">
                <xsl:text> </xsl:text>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <!--Texthervorhebungen-->
    <xsl:template match="tei:hi">
        <xsl:choose>
            <xsl:when test=".[@rend = 'bold']">
                <fo:inline font-family="{$ftSfBd}">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test=".[@rend = 'ul']">
                <fo:inline text-decoration="underline">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test=".[@rend = 'italic']">
                <fo:inline font-family="{$ftSfObl}">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test=".[ancestor::tei:bibl]">
                <fo:inline font-family="{$ftSfObl}">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test=".[parent::tei:rs[contains(@type, 'Top_Referenz')]]">
                <fo:inline font-family="{$ftSfObl}">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline font-family="{$ftSfObl}">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="tei:rs[@type = 'Sprecher']">
        <fo:inline font-family="{$ftSfObl}" id="{generate-id()}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:foreign">
        <fo:inline font-family="{$ftSfObl}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <!--Sachschlagworts-Elemente entfernen-->
    <xsl:template match="tei:index[@indexName = 'Sachschlagwörter']"/>
    <xsl:template match="tei:anchor[@type = 'Sachschlagwörter']"/>

    <xsl:template match="tei:lb">
        <fo:block/>
    </xsl:template>

    <!--Leeres Template um Zeitwerte aus Datumszeile zu entfernen-->
    <xsl:template match="tei:time" mode="ohnezeit"/>

    <xsl:template match="tei:p" mode="fn">
        <xsl:apply-templates/>
    </xsl:template>


    <!-- - - - - - - - - - -    BIOGRAMMPLATZHALTER - - - - - - - - - - -->
    <xsl:template match="tei:ref[@type = 'Biogramm_Platzhalter']">
        <xsl:variable name="placeholderID">
            <xsl:value-of select="./@target"/>
        </xsl:variable>
        <xsl:variable name="placeholderValue">
            <xsl:value-of select="$per//tei:person[@xml:id = $placeholderID]/tei:note[@type = 'Biogramm']"/>
        </xsl:variable>

        <!--Falls Biogramm noch nicht ausgefüllt ist bleibt der Biogrammplatzhalter stehen-->
        <fo:inline id="{generate-id()}">
            <xsl:choose>
                <xsl:when test="$placeholderValue != ''">
                    <xsl:apply-templates select="$per//tei:person[@xml:id = $placeholderID]/tei:note[@type = 'Biogramm']"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:note[@type = 'Biogramm']">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:note[@type = 'Biogramm']/tei:name[@type = 'Hervorhebung']">
        <fo:inline font-family="{$ftSfObl}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>


    <!-- - - - - - - - - - -    ANMERKUNGSREFERENZEN    - - - - - - - - - - -->
    <xsl:template match="tei:ref[@type = 'Anmerkungsreferenz']">

        <xsl:variable name="key" select="@target"/>
        <xsl:variable name="targetVolumePath" select="hiko:getVolumePath($key)"/>
        <xsl:variable name="targetDocTypePath" select="hiko:getDocTypePath($key)"/>
        <xsl:variable name="targetDocID" select="hiko:getNoteReferenceDocumentName($key)"/>

        <xsl:variable name="targetdoc_path">
            <xsl:value-of select="concat($edition_path, $targetVolumePath, $targetDocTypePath, '/', $targetDocID, '.xml')"/>
        </xsl:variable>
        <xsl:variable name="targetdoc" select="document($targetdoc_path)"/>

        <fo:inline>
            <xsl:apply-templates select="$targetdoc//tei:note[@xml:id = $key]" mode="anmerkungsreferenz">
                <xsl:with-param name="targetDocID" select="$targetDocID"/>
            </xsl:apply-templates>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:note" mode="anmerkungsreferenz">
        <xsl:param name="targetDocID"/>

        <xsl:variable name="volumeText" select="hiko:getVolumeText($targetDocID)"/>
        <xsl:variable name="docText" select="hiko:getDocText($targetDocID)"/>

        <xsl:value-of select="$volumeText"/>
        <xsl:value-of select="$docText"/>

        <!-- Wenn der Verweis auf eine Fußnote im selben Protokoll geht -> Leerzeichen vor dem Anmerkungstext weglassen -->
        <xsl:if test="not(empty($docText))">
            <xsl:text> </xsl:text>
        </xsl:if>
        <xsl:text>Anm. </xsl:text>
        <xsl:value-of select="count(preceding::tei:note) + 1"/>
    </xsl:template>


    <!-- - - - - - - - - - -    PTVZ    - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Protokollzusammenfassung']">
        <fo:table width="190mm" margin-bottom="2mm" border-separation="0" border-collapse="collapse">
            <fo:table-body>
                <fo:table-row margin-bottom="0.5em">
                    <fo:table-cell width="25mm" padding="2.5mm">
                        <xsl:apply-templates select="./tei:head/tei:num" mode="ptvz"/>
                    </fo:table-cell>
                    <fo:table-cell width="25mm" padding="2.5mm">
                        <xsl:apply-templates select="./tei:head/tei:date" mode="ptvz"/>
                    </fo:table-cell>
                    <fo:table-cell width="100mm" padding="2.5mm">
                        <xsl:apply-templates select="./tei:head/tei:title" mode="ptvz"/>
                    </fo:table-cell>
                    <fo:table-cell width="20mm" padding="2.5mm">
                        <fo:block text-align="right">S. XXX</fo:block>
                    </fo:table-cell>
                </fo:table-row>
                <fo:table-row>
                    <fo:table-cell padding="2.5mm">
                        <fo:block/>
                    </fo:table-cell>
                    <fo:table-cell padding="2.5mm">
                        <fo:block/>
                    </fo:table-cell>
                    <fo:table-cell padding="2.5mm" font-size="{$ftsz_PTVZTO}">
                        <xsl:apply-templates select=".//tei:p" mode="ptvz"/>
                    </fo:table-cell>
                    <fo:table-cell padding="2.5mm">
                        <fo:block/>
                    </fo:table-cell>
                </fo:table-row>
            </fo:table-body>
        </fo:table>
    </xsl:template>

    <xsl:template match="tei:head" mode="ptvz">
        <fo:block>
            <xsl:apply-templates mode="ptvz"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:num" mode="ptvz">
        <fo:block>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:date" mode="ptvz">
        <fo:block>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:title" mode="ptvz">
        <fo:block>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:p" mode="ptvz">
        <fo:block text-align="justify" line-height="115%">
            <xsl:apply-templates mode="ptvz"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:rs[@type = 'Top_Link']" mode="ptvz">
        <fo:inline>
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>


    <!-- - - - - - - - - - -    DOLMETSCHERPROTOKOLLE   - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Besprechungsabschnitt']">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Besprechungsabschnitt']/tei:head">
        <fo:block text-align="left" space-before="3.5mm" space-after="1mm" font-family="{$ftSfObl}">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Besprechungsabschnitt']/tei:head/tei:num">
        <fo:inline>
            <xsl:apply-templates/>
            <xsl:text> </xsl:text>
        </fo:inline>
    </xsl:template>


    <!-- - - - - - - - - - -    ABSCHNITTSÜBERSCHRIFTEN - - - - - - - - - - -->
    <xsl:template match="tei:head[@type = 'Abschnittsüberschrift']">
        <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Überschrift_Abschnitt}" space-after="3.5mm">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:body/tei:head[@type != 'Abschnittsüberschrift']">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:body/tei:head/tei:num">
        <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Überschrift_Abschnitt}" space-after="3.5mm" text-align="center">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:body/tei:head/tei:date">
        <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Überschrift_Abschnitt}" space-before="1mm" space-after="3.5mm" text-align="right">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>


    <!-- - - - - - - - - - -    SONDERFORMEN    - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Protokolltextabschnitt']">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Protokolltextabschnitt']/tei:head">
        <fo:block text-align="center" space-before="3.5mm" space-after="1mm">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <!-- - - - - - - - - - -    DRUCKREGISTER   - - - - - - - - - - -->
    <xsl:template match="tei:list[@n]">
        <xsl:variable name="ebene">
            <xsl:value-of select="@n"/>
        </xsl:variable>
        
        <!-- Einträge auf oberster Ebene werden eingerückt wie Einträge auf zweiter Ebene-->
        <xsl:variable name="einrueckEbene">
            <xsl:choose>
                <xsl:when test="$ebene = 0">
                    <xsl:value-of select="'1'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$ebene"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="margin-top">
            <xsl:choose>
                <xsl:when test="./@rend = 'lettergap'">
                    <xsl:value-of select="'1.05em'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'0'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        <fo:block start-indent="{$einrueckEbene} *2.4mm" text-indent="{$einrueckEbene} * -2.4mm" font-size="{$ftsz_zweispaltRegister}" line-height="105%" margin-top="{$margin-top}" page-break-inside="auto" orphans="1" widows="2" text-align="left">
            <fo:inline>
                <xsl:apply-templates/>
            </fo:inline>
        </fo:block>
    </xsl:template>



    <!-- - - - - - - - - - -    FUNKTIONEN  - - - - - - - - - - -->
    <!--Eigene Datumseresetzungsfunktion; Autor: MR-->
    <xsl:function name="my:replMonth">
        <xsl:param name="t"/>
        <xsl:value-of select="replace(replace(replace(replace(replace(replace(replace(replace($t, 'January', 'Januar'), 'February', 'Februar'), 'March', 'März'), 'May', 'Mai'), 'June', 'Juni'), 'July', 'Juli'), 'October', 'Oktober'), 'December', 'Dezember')"/>
    </xsl:function>

    <!-- Eigene Funktion zum ermitteln der gesuchten Datei bei einer Anmerkungsreferez; Autor: mXs-->
    <xsl:function name="hiko:getNoteReferenceDocumentName">
        <xsl:param name="targetDocID"/>
        <xsl:variable name="note_document" select="tokenize($targetDocID, '_')[1]"/>
        <xsl:variable name="document_name" select="tokenize($note_document, '-')[2]"/>
        <xsl:value-of select="$document_name"/>
    </xsl:function>

    <!-- Eigene Funktion zur Ermittlung des Bandordners in dem sich ein bestimmtes Editionsdokument befindet; Autor: mXs-->
    <xsl:function name="hiko:getVolumePath">
        <xsl:param name="targetID"/>
        <xsl:variable name="volume" select="substring($targetID, 4,5)"/>
        
        <xsl:choose>
            <xsl:when test="$volume = 'ehr33'">
                <xsl:value-of select="$ehr33_path"/>        
            </xsl:when>
            <xsl:when test="$volume = 'ehr34'">
                <xsl:value-of select="$ehr34_path"/>
            </xsl:when>
            <xsl:when test="$volume = 'hoe21'">
                <xsl:value-of select="$hoe21_path"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="'error'"/>
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:function>

    <!-- Eigene Funktion zur Ermittlung des Dokumentenunterordners in dem sich ein bestimmtes Editionsdokument befindet; Autor: mXs -->
    <xsl:function name="hiko:getDocTypePath">
        <xsl:param name="targetDocID"/>
        <xsl:variable name="documentType" select="substring($targetDocID,9,1)"/>
        
        <xsl:choose>
            <xsl:when test="$documentType = 'p'">
                <xsl:value-of select="$protokoll_path"/>
            </xsl:when>
            <xsl:when test="$documentType = 'a'">
                <xsl:value-of select="$abschnitt_path"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="'error'"/>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:function>    

    <!-- Eigene Funktion um den einzufügenden Bandnamen für eine Anmerkungsreferenz zu ermitteln und zusammenzustellen; Autor: mXs -->
    <xsl:function name="hiko:getVolumeText">
        <xsl:param name="targetDocID"/>

        <!-- BandIDs aus DokumentIDs herauslesenen -->
        <xsl:variable name="targetVolume">
            <xsl:value-of select="substring($targetDocID, 1, 5)"/>
        </xsl:variable>
        <xsl:variable name="currentVolume">
            <xsl:value-of select="substring($currentDocID, 1, 5)"/>
        </xsl:variable>

        <!-- gesuchter Band und bearbeiteter Band gleich => nichts einfügen -->
        <xsl:choose>
            <xsl:when test="$targetVolume = $currentVolume">
                <xsl:value-of select="''"/>
            </xsl:when>
            <!-- Fallunterscheidung nach Band -->
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="$targetVolume = 'ehr33'">
                        <xsl:value-of select="$ehr33_refText"/>
                        <xsl:text> </xsl:text>
                    </xsl:when>
                    <xsl:when test="$targetVolume = 'ehr34'">
                        <xsl:value-of select="$ehr34_refText"/>
                        <xsl:text> </xsl:text>
                    </xsl:when>
                    <xsl:when test="$targetVolume = 'hoe21'">
                        <xsl:value-of select="$hoe21_refText"/>
                        <xsl:text> </xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <fo:inline font-family="{$ftSFBdObl}">UNBEKANNTER BAND</fo:inline>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>

    <!-- TODO Eigene Funktion um den/die einzufügende/n Protokoll/Abschnittsnamen für eine Anmerkungsreferenz zu ermitteln und zusammenzustellen -->
    <xsl:function name="hiko:getDocText">
        <xsl:param name="targetDocID"/>
            
        <xsl:choose>
            <xsl:when test="$targetDocID != $currentDocID">
                <!--Fallunterscheidung Protokolle/Editionsabschnitte-->                
                <xsl:variable name="documentType" select="substring($targetDocID,6,1)"/>
                
                <xsl:choose>
                    <xsl:when test="$documentType = 'a'">
                        <xsl:variable name="targetDocAbrev" select="substring($targetDocID, 7, 4)"/>
                        
                        <xsl:choose>
                            <xsl:when test="$targetDocAbrev = 'EDGS'">
                                <fo:inline>Editionsgrundsätze </fo:inline>
                            </xsl:when>
                            <xsl:when test="$targetDocAbrev = 'ENLT'">
                                <fo:inline>Einleitung </fo:inline>
                            </xsl:when>
                            <xsl:otherwise>
                                <fo:inline font-family="{$ftSFBdObl}">UNBEKANNTER EDITIONSABSCHNITT</fo:inline>
                            </xsl:otherwise>
                        </xsl:choose>                        
                    </xsl:when>
                    
                    <xsl:when test="$documentType = 'p'">
                        <xsl:variable name="targetDocNum" select="substring($targetDocID, 7, 3)"/>
                        <xsl:variable name="targetDocNumWithLeadingZeros" select="substring(concat('000', $targetDocNum), string-length($targetDocNum) +1, 3)"/>
                        <fo:inline>Nr. <xsl:value-of select="$targetDocNumWithLeadingZeros"/></fo:inline>
                    </xsl:when>
                    
                    <xsl:otherwise>
                        <fo:inline font-family="{$ftSFBdObl}">UNBEKANNTER DOKUMENTTYP</fo:inline>
                    </xsl:otherwise>
                </xsl:choose>                
            </xsl:when>
        </xsl:choose>
    </xsl:function>

    <xsl:template match="processing-instruction('shy')">
        <xsl:text>-&#x200b;</xsl:text>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Freiblock' and ./preceding-sibling::tei:div[@type = 'Top']]">
        <xsl:variable name="space-before">
            <xsl:choose>
                <xsl:when test="./preceding-sibling::tei:div[@type = 'Top']">
                    <xsl:value-of select="'3mm'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="0"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:block line-height="115%" space-before="{$space-before}">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

</xsl:stylesheet>
