<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xi="http://www.w3.org/2001/XInclude" xmlns:tei="http://www.tei-c.org/ns/1.0"
    exclude-result-prefixes="xs xi tei" version="2.0" xmlns:hiko="http://www.historischekommission-muenchen.de">

    <xsl:import href="../../tei_oxydition_minrprot/transformations/Druck/minrprot_druck_pdf.xsl"/>
    <xsl:import href="minrprot_gesamt_integration_durchfuehrung.xsl"/>

    <!-- Variante der Gesamtdruckdatei. Gibt OSRG und PSRG einspaltig, ohne Silbentrennung und (bei OSRG)
        mit vereinfachten Schachtelungsstrichen und Leerzeichen aus. Dies dient der Weiterverarbeitung zum korrigierten Druckregister-->

    <!-- - - - - - - - - - -    GESAMTDATEI INTEGRIEREN UND AN DRUCKTEMPLATES ÜBERGEBEN  - - - - - - - - - - -->
    <xsl:template match="/">
        <xsl:variable name="integration">
            <xsl:call-template name="init_integration"/>
        </xsl:variable>
        <xsl:call-template name="init_druck">
            <xsl:with-param name="integrierter_Text" select="$integration"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="init_druck">
        <xsl:param name="integrierter_Text"/>
        <xsl:apply-templates select="$integrierter_Text//tei:TEI"/>
    </xsl:template>

    <!-- - - - - - - - - - -    DRUCKTEMPLATES - - - - - - - - - - -->
    <xsl:template match="//tei:TEI">
        <fo:root font-size="{$ftsz_Fließtext}" font-family="{$ftSf}" line-height="115%" xml:lang="de" hyphenate="true"
            line-height-shift-adjustment="disregard-shifts" hyphenation-push-character-count="4" hyphenation-remain-character-count="4"
            language="de">
            <fo:layout-master-set>
                <fo:simple-page-master master-name="PageMaster.Inhalt-rechts" margin-top="12mm" margin-bottom="30mm" margin-left="17mm"
                    margin-right="21mm" page-height="235mm" page-width="155mm">
                    <fo:region-body margin-top="9mm"/>
                    <fo:region-before region-name="Inhalt-rechts-davor" extent="15mm" display-align="before" border-after-style="solid"
                        padding="0" border="0"/>
                </fo:simple-page-master>
                <fo:simple-page-master master-name="PageMaster.Inhalt-links" margin-top="12mm" margin-bottom="30mm" margin-left="21mm"
                    margin-right="17mm" page-height="235mm" page-width="155mm">
                    <fo:region-body margin-top="9mm"/>
                    <fo:region-before region-name="Inhalt-links-davor" extent="15mm" display-align="before" border-after-style="solid"
                        padding="0" border="0"/>
                </fo:simple-page-master>
                <fo:simple-page-master master-name="PageMaster.Inhalt-rechts-start" margin-top="12mm" margin-bottom="30mm"
                    margin-left="17mm" margin-right="21mm" page-height="235mm" page-width="155mm">
                    <fo:region-body margin-top="9mm"/>
                    <fo:region-before region-name="Inhalt-rechts-davor-start" extent="15mm" display-align="before"
                        border-after-style="solid" padding="0" border="0"/>
                </fo:simple-page-master>
                <fo:simple-page-master master-name="PageMaster.Inhalt-links-start" margin-top="12mm" margin-bottom="30mm" margin-left="21mm"
                    margin-right="17mm" page-height="235mm" page-width="155mm">
                    <fo:region-body margin-top="9mm"/>
                    <fo:region-before region-name="Inhalt-links-davor-start" extent="15mm" display-align="before" border-after-style="solid"
                        padding="0" border="0"/>
                </fo:simple-page-master>
                <fo:simple-page-master master-name="PageMaster.Teil-Titelseite" margin-top="12mm" margin-bottom="30mm" margin-left="17mm"
                    margin-right="21mm" page-height="235mm" page-width="155mm">
                    <fo:region-body region-name="Teil-Titelseite-Hauptbereich" margin="0mm 0mm 0mm 0mm"/>
                </fo:simple-page-master>
                <fo:simple-page-master master-name="PageMaster.Leer" margin-top="12mm" margin-bottom="30mm" margin-left="21mm"
                    margin-right="17mm" page-height="235mm" page-width="155mm">
                    <fo:region-body/>
                </fo:simple-page-master>

                <!-- Register - wie Inhalt nur Spalten = 2 -->
                <fo:simple-page-master master-name="PageMaster.Register-rechts" margin-top="12mm" margin-bottom="30mm" margin-left="17mm"
                    margin-right="21mm" page-height="235mm" page-width="155mm">
                    <fo:region-body margin-top="9mm" column-count="2" column-gap="4mm"/>
                    <fo:region-before region-name="Register-rechts-davor" extent="15mm" display-align="before" border-after-style="solid"
                        padding="0" border="0"/>
                </fo:simple-page-master>
                <fo:simple-page-master master-name="PageMaster.Register-links" margin-top="12mm" margin-bottom="30mm" margin-left="21mm"
                    margin-right="17mm" page-height="235mm" page-width="155mm">
                    <fo:region-body margin-top="9mm" column-count="2" column-gap="4mm"/>
                    <fo:region-before region-name="Register-links-davor" extent="15mm" display-align="before" border-after-style="solid"
                        padding="0" border="0"/>
                </fo:simple-page-master>
                <fo:simple-page-master master-name="PageMaster.Register-rechts-start" margin-top="12mm" margin-bottom="30mm"
                    margin-left="17mm" margin-right="21mm" page-height="235mm" page-width="155mm">
                    <fo:region-body margin-top="9mm" column-count="2" column-gap="4mm"/>
                    <fo:region-before region-name="Register-rechts-davor-start" extent="15mm" display-align="before"
                        border-after-style="solid" padding="0" border="0"/>
                </fo:simple-page-master>
                <fo:simple-page-master master-name="PageMaster.Register-links-start" margin-top="12mm" margin-bottom="30mm"
                    margin-left="21mm" margin-right="17mm" page-height="235mm" page-width="155mm">
                    <fo:region-body margin-top="9mm" column-count="2" column-gap="4mm"/>
                    <fo:region-before region-name="Register-links-davor-start" extent="15mm" display-align="before"
                        border-after-style="solid" padding="0" border="0"/>
                </fo:simple-page-master>


                <fo:page-sequence-master master-name="Teil-Seiten">
                    <fo:repeatable-page-master-reference master-reference="PageMaster.Teil-Titelseite"/>
                </fo:page-sequence-master>


                <fo:page-sequence-master master-name="Inhalt-Seiten">
                    <fo:repeatable-page-master-alternatives>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-links-start" page-position="first"
                            odd-or-even="even"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-rechts-start" page-position="first"
                            odd-or-even="odd"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Leer" blank-or-not-blank="blank"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-links" page-position="rest"
                            odd-or-even="even"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-rechts" page-position="rest"
                            odd-or-even="odd"/>
                    </fo:repeatable-page-master-alternatives>
                </fo:page-sequence-master>
                <fo:page-sequence-master master-name="Register-Seiten">
                    <fo:repeatable-page-master-alternatives>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Register-links-start" page-position="first"
                            odd-or-even="even"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Register-rechts-start" page-position="first"
                            odd-or-even="odd"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Register-links" page-position="rest"
                            odd-or-even="even"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Register-rechts" page-position="rest"
                            odd-or-even="odd"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Register-links" page-position="last"
                            odd-or-even="even"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Register-rechts" page-position="last"
                            odd-or-even="odd"/>
                    </fo:repeatable-page-master-alternatives>
                </fo:page-sequence-master>
            </fo:layout-master-set>

            <xsl:for-each select="/tei:TEI/tei:text/tei:group/*">
                <!-- Fallunterscheidung für die verschiedenen Dokumentstypen -->
                <xsl:choose>

                    <!-- - - - - - - - - - -    TITELEI - - - - - - - - - - -->
                    <xsl:when test="local-name() = 'text' and @n = 'Titelei'">
                        <fo:page-sequence master-reference="Inhalt-Seiten" initial-page-number="1" format="I">
                            <fo:flow flow-name="xsl-region-body">
                                <fo:block id="{generate-id()}">
                                    <xsl:choose>
                                        <xsl:when test=".//xi:include">
                                            <xsl:apply-templates select="document(.//*:include/@href)//tei:body"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:apply-templates select=".//tei:body"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </fo:block>
                            </fo:flow>
                        </fo:page-sequence>
                    </xsl:when>

                    <!-- - - - - - - - - - -    INHALTSVERZEICHNIS  - - - - - - - - - - -->
                    <xsl:when test="local-name() = 'text' and @n = 'Inhaltsverzeichnis'">

                        <fo:page-sequence master-reference="Inhalt-Seiten" initial-page-number="5" format="I">
                            <fo:static-content flow-name="Inhalt-rechts-davor-start">
                                <fo:block text-align="end" font-size="{$ftsz_Kopfzeile}" border-after-style="solid"
                                    border-after-width="0.5pt" border-after-color="black">&#x00a0;</fo:block>
                            </fo:static-content>

                            <fo:flow flow-name="xsl-region-body">

                                <fo:block id="{generate-id()}" font-size="{$ftsz_Überschrift_Abschnitt}" font-weight="bold"
                                    text-align="center" space-after="16mm">Inhaltsverzeichnis</fo:block>

                                <xsl:for-each select="//tei:text[./tei:front/tei:head != 'Inhaltsverzeichnis']">
                                    <xsl:choose>
                                        <xsl:when test="./tei:front/tei:head = 'Einleitung'">
                                            <xsl:call-template name="ivz.enlt"/>
                                        </xsl:when>
                                        <xsl:when test="./@n = 'PER'">
                                            <xsl:call-template name="ivz.psrg"/>
                                        </xsl:when>
                                        <xsl:when test="./@n = 'SSW'">
                                            <xsl:call-template name="ivz.osrg"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:call-template name="ivz.zeile"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:for-each>
                            </fo:flow>
                        </fo:page-sequence>
                    </xsl:when>

                    <!-- - - - - - - - - - -    EDITIONSABSCHNITTE  - - - - - - - - - - -->
                    <xsl:when test="local-name() = 'text'">
                        <xsl:variable name="head" select="tei:front/tei:head"/>

                        <fo:page-sequence master-reference="Inhalt-Seiten" force-page-count="end-on-even" initial-page-number="auto-odd"
                            format="I">
                            <xsl:if test="not(preceding-sibling::*)">
                                <xsl:attribute name="initial-page-number">1</xsl:attribute>
                            </xsl:if>

                            <fo:static-content flow-name="xsl-footnote-separator">
                                <fo:block text-align="justify">
                                    <fo:leader leader-length="50%" rule-thickness="2.5mm" leader-pattern="space"/>
                                </fo:block>
                            </fo:static-content>

                            <!--Kopfbereich erste Seite rechts - nur schwarzer Querstrich-->
                            <fo:static-content flow-name="Inhalt-rechts-davor-start">
                                <fo:block text-align="end" font-size="{$ftsz_Kopfzeile}" border-after-style="solid"
                                    border-after-width="0.5pt" border-after-color="black">&#x00a0;</fo:block>
                            </fo:static-content>

                            <!--Kopfbereich Folgeseiten rechts - scharzer Querstrich, Abschnittstitel links, Seitenzahl rechts-->
                            <fo:static-content flow-name="Inhalt-rechts-davor">
                                <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt"
                                    border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                    <fo:table-column column-width="87mm"/>
                                    <fo:table-column column-width="10mm"/>
                                    <fo:table-column column-width="20mm"/>
                                    <fo:table-body>
                                        <fo:table-row>
                                            <fo:table-cell text-align="start">
                                                <fo:block>
                                                    <xsl:value-of select="$head"/>
                                                </fo:block>
                                            </fo:table-cell>
                                            <fo:table-cell text-align="center">
                                                <fo:block/>
                                            </fo:table-cell>
                                            <fo:table-cell text-align="end">
                                                <fo:block font-size="{$ftsz_Seitenzahl}">
                                                    <fo:page-number/>
                                                </fo:block>
                                            </fo:table-cell>
                                        </fo:table-row>
                                    </fo:table-body>
                                </fo:table>
                            </fo:static-content>

                            <!--Kopfbereich Folgeseiten links - scharzer Querstrich, Seitenzahl links, Abschnittstitel rechts-->
                            <fo:static-content flow-name="Inhalt-links-davor">
                                <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt"
                                    border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                    <fo:table-column column-width="20mm"/>
                                    <fo:table-column column-width="10mm"/>
                                    <fo:table-column column-width="87mm"/>
                                    <fo:table-body>
                                        <fo:table-row>
                                            <fo:table-cell text-align="start">
                                                <fo:block font-size="{$ftsz_Seitenzahl}">
                                                    <fo:page-number/>
                                                </fo:block>
                                            </fo:table-cell>
                                            <fo:table-cell text-align="center">
                                                <fo:block/>
                                            </fo:table-cell>
                                            <fo:table-cell text-align="end">
                                                <fo:block>
                                                    <xsl:value-of select="$head"/>
                                                </fo:block>
                                            </fo:table-cell>
                                        </fo:table-row>
                                    </fo:table-body>
                                </fo:table>
                            </fo:static-content>

                            <fo:flow flow-name="xsl-region-body">
                                <fo:block id="{generate-id()}">

                                    <xsl:choose>
                                        <xsl:when test=".//xi:include">
                                            <xsl:apply-templates select="document(.//*:include/@href)//tei:body"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:apply-templates select=".//tei:body"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </fo:block>
                            </fo:flow>
                        </fo:page-sequence>
                    </xsl:when>

                    <!-- - - - - - - - - - -    PROTOKOLLE  - - - - - - - - - - -->
                    <xsl:when test="local-name() = 'group' and @n = 'Protokolle'">

                        <xsl:for-each select="tei:text">
                            <fo:page-sequence master-reference="Inhalt-Seiten" format="1">
                                <xsl:if test="not(preceding-sibling::tei:text)">
                                    <xsl:attribute name="initial-page-number">1</xsl:attribute>
                                </xsl:if>

                                <fo:static-content flow-name="xsl-footnote-separator">
                                    <fo:block text-align="justify">
                                        <fo:leader leader-length="50%" rule-thickness="2.5mm" leader-pattern="space"/>
                                    </fo:block>
                                </fo:static-content>

                                <!--Kopfbereich erste Seite rechts - nur schwarzer Querstrich-->
                                <fo:static-content flow-name="Inhalt-rechts-davor-start">
                                    <fo:block text-align="end" font-size="{$ftsz_Kopfzeile}" border-after-style="solid"
                                        border-after-width="0.5pt" border-after-color="black">&#x00a0;</fo:block>
                                </fo:static-content>

                                <!--Kopfbereich erste Seite links - nur schwarzer Querstrich-->
                                <fo:static-content flow-name="Inhalt-links-davor-start">
                                    <fo:block text-align="end" font-size="{$ftsz_Kopfzeile}" border-after-style="solid"
                                        border-after-width="0.5pt" border-after-color="black">&#x00a0;</fo:block>
                                </fo:static-content>

                                <!--Kopfbereich Folgeseiten rechts - schwarzer Querstrich, links Protokollnummer, mitte Datum, rechts Seitenzahl-->
                                <fo:static-content flow-name="Inhalt-rechts-davor">
                                    <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt"
                                        border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                        <fo:table-column column-width="20mm"/>
                                        <fo:table-column column-width="77mm"/>
                                        <fo:table-column column-width="20mm"/>
                                        <fo:table-body>
                                            <fo:table-row>
                                                <fo:table-cell text-align="start">
                                                    <fo:block>
                                                        <fo:retrieve-marker retrieve-class-name="protokollnummer"
                                                            retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"
                                                        />
                                                    </fo:block>
                                                </fo:table-cell>
                                                <fo:table-cell text-align="center">
                                                    <fo:block>
                                                        <fo:retrieve-marker retrieve-class-name="protokolldatum"
                                                            retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"
                                                        />
                                                    </fo:block>
                                                </fo:table-cell>
                                                <fo:table-cell text-align="end">
                                                    <fo:block font-size="{$ftsz_Seitenzahl}">
                                                        <fo:page-number/>
                                                    </fo:block>
                                                </fo:table-cell>
                                            </fo:table-row>
                                        </fo:table-body>
                                    </fo:table>
                                </fo:static-content>

                                <!--Kopfbereich Folgeseiten rechts - schwarzer Querstrich, links Seitenzahl, mitte Datum, rechts Protokollnummer-->
                                <fo:static-content flow-name="Inhalt-links-davor">
                                    <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt"
                                        border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                        <fo:table-column column-width="20mm"/>
                                        <fo:table-column column-width="77mm"/>
                                        <fo:table-column column-width="20mm"/>
                                        <fo:table-body>
                                            <fo:table-row>
                                                <fo:table-cell text-align="start">
                                                    <fo:block font-size="{$ftsz_Seitenzahl}">
                                                        <fo:page-number/>
                                                    </fo:block>
                                                </fo:table-cell>
                                                <fo:table-cell text-align="center">
                                                    <fo:block>
                                                        <fo:retrieve-marker retrieve-class-name="protokolldatum"
                                                            retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"
                                                        />
                                                    </fo:block>
                                                </fo:table-cell>
                                                <fo:table-cell text-align="end">
                                                    <fo:block>
                                                        <fo:retrieve-marker retrieve-class-name="protokollnummer"
                                                            retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"
                                                        />
                                                    </fo:block>
                                                </fo:table-cell>
                                            </fo:table-row>
                                        </fo:table-body>
                                    </fo:table>
                                </fo:static-content>

                                <fo:flow flow-name="xsl-region-body">

                                    <xsl:choose>
                                        <xsl:when test=".//xi:include">
                                            <xsl:apply-templates select="document(.//*:include/@href)//tei:body"/>
                                        </xsl:when>
                                        <xsl:otherwise>

                                            <!-- Hauptdok ? neuer Kolumentitel : "" -->
                                            <fo:block-container keep-together="always">
                                                <fo:block text-align="center" id="{generate-id()}">
                                                    <xsl:if test="not(parent::tei:group[@n = 'dok'])">
                                                        <fo:marker marker-class-name="ProtokollNummer">
                                                            <xsl:value-of select="tei:div[@type = 'Protokollnummer']/tei:head/tei:num"/>
                                                        </fo:marker>
                                                    </xsl:if>
                                                    <xsl:apply-templates select="tei:front/tei:head"/>
                                                </fo:block>
                                            </fo:block-container>
                                            <xsl:apply-templates select=".//tei:body"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </fo:flow>
                            </fo:page-sequence>
                        </xsl:for-each>
                    </xsl:when>

                    <!-- - - - - - - - - - -    REGISTER    - - - - - - - - - - -->
                    <xsl:when test="local-name() = 'group' and @n = 'Register'">

                        <!-- Alle Register einspaltig setzen -->
                        <xsl:for-each select="tei:text[@type = 'einspaltig' or @type = 'zweispaltig']">
                            <fo:page-sequence master-reference="Inhalt-Seiten">
                                <fo:static-content flow-name="xsl-footnote-separator">
                                    <fo:block text-align="justify">
                                        <fo:leader leader-length="50%" rule-thickness="2.5mm" leader-pattern="space"/>
                                    </fo:block>
                                </fo:static-content>

                                <!--Kopfbereich erste Seite rechts - nur schwarzer Querstrich-->
                                <fo:static-content flow-name="Inhalt-rechts-davor-start">
                                    <fo:block text-align="end" font-size="{$ftsz_Kopfzeile}" border-after-style="solid"
                                        border-after-width="0.5pt" border-after-color="black">&#x00a0;</fo:block>
                                </fo:static-content>

                                <!--Kopfbereich erste Seite rechts - nur schwarzer Querstrich-->
                                <fo:static-content flow-name="Inhalt-links-davor-start">
                                    <fo:block text-align="end" font-size="{$ftsz_Kopfzeile}" border-after-style="solid"
                                        border-after-width="0.5pt" border-after-color="black">&#x00a0;</fo:block>
                                </fo:static-content>

                                <!--Kopfbereich Folgeseiten links - scharzer Querstrich, Registertitel links, Seitenzahl rechts-->
                                <fo:static-content flow-name="Inhalt-rechts-davor">
                                    <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt"
                                        border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                        <fo:table-column column-width="87mm"/>
                                        <fo:table-column column-width="10mm"/>
                                        <fo:table-column column-width="20mm"/>
                                        <fo:table-body>
                                            <fo:table-row>
                                                <fo:table-cell text-align="start">
                                                    <fo:block>
                                                        <fo:retrieve-marker retrieve-class-name="registertitel"
                                                            retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"
                                                        />
                                                    </fo:block>
                                                </fo:table-cell>
                                                <fo:table-cell text-align="center">
                                                    <fo:block/>
                                                </fo:table-cell>
                                                <fo:table-cell text-align="end">
                                                    <fo:block font-size="{$ftsz_Seitenzahl}">
                                                        <fo:page-number/>
                                                    </fo:block>
                                                </fo:table-cell>
                                            </fo:table-row>
                                        </fo:table-body>
                                    </fo:table>
                                </fo:static-content>

                                <!--Kopfbereich Folgeseiten links - scharzer Querstrich, Seitenzahl links, Registertitel rechts-->
                                <fo:static-content flow-name="Inhalt-links-davor">
                                    <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt"
                                        border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                        <fo:table-column column-width="20mm"/>
                                        <fo:table-column column-width="10mm"/>
                                        <fo:table-column column-width="87mm"/>
                                        <fo:table-body>
                                            <fo:table-row>
                                                <fo:table-cell text-align="start">
                                                    <fo:block font-size="{$ftsz_Seitenzahl}">
                                                        <fo:page-number/>
                                                    </fo:block>
                                                </fo:table-cell>
                                                <fo:table-cell text-align="center">
                                                    <fo:block/>
                                                </fo:table-cell>
                                                <fo:table-cell text-align="end">
                                                    <fo:block>
                                                        <fo:retrieve-marker retrieve-class-name="registertitel"
                                                            retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"
                                                        />
                                                    </fo:block>
                                                </fo:table-cell>
                                            </fo:table-row>
                                        </fo:table-body>
                                    </fo:table>
                                </fo:static-content>

                                <fo:flow flow-name="xsl-region-body">
                                    <fo:block id="{generate-id()}">
                                        <xsl:apply-templates select="."/>
                                    </fo:block>
                                </fo:flow>
                            </fo:page-sequence>
                        </xsl:for-each>
                    </xsl:when>
                    <xsl:otherwise> EXCEPTION </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </fo:root>
    </xsl:template>

    <!-- - - - - - - - - - -    ANMERKUNGSREFERENZEN    - - - - - - - - - - -->
    <xsl:template match="tei:ref[@type = 'Anmerkungsreferenz']">

        <xsl:variable name="key">
            <xsl:value-of select="./@target"/>
        </xsl:variable>
        <xsl:variable name="targetDocID" select="hiko:getNoteReferenceDocumentName($key)"/>
        <xsl:variable name="referingDocID" select="hiko:getDocumentID(.)"/>
        <xsl:variable name="root" select="//tei:TEI"/>


        <fo:inline>
            <xsl:variable name="targetDocVolume" select="substring($targetDocID, 1, 5)"/>
            <xsl:variable name="referingDocVolume" select="substring($referingDocID, 1, 5)"/>

            <xsl:choose>
                <!-- Unterscheidung: Verweis auf Fußnote in selbem oder in anderem Band -->
                <xsl:when test="$targetDocVolume = $referingDocVolume">
                    <xsl:apply-templates select="//tei:note[@xml:id = $key]" mode="anmerkungsreferenz_gesamt">
                        <xsl:with-param name="targetDocID" select="$targetDocID"/>
                        <xsl:with-param name="referingDocID" select="$referingDocID"/>
                    </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                    <!-- Die "druckfinal-Datei", die der letzten Gesamtdatei vor der Drucklegung entspricht, dient als Bezugspunkt für die Rekonstruktion der Anmerkungsreferenz-->
                    <xsl:variable name="targetVolumePath" select="hiko:getVolumePath($targetDocID)"/>
                    <xsl:variable name="targetFullDocumentPath"
                        select="concat($edition_path, $targetVolumePath, '/', $targetDocVolume, '_gesamt_druckfinal.xml')"/>
                    <xsl:variable name="targetFullDoc" select="document($targetFullDocumentPath)"/>
                    <xsl:choose>
                        <xsl:when test="$targetFullDoc//tei:note[@xml:id = $key]">
                            <xsl:apply-templates select="$targetFullDoc//tei:note[@xml:id = $key]" mode="anmerkungsreferenz_gesamt">
                                <xsl:with-param name="targetDocID" select="$targetDocID"/>
                                <xsl:with-param name="referingDocID" select="$referingDocID"/>
                            </xsl:apply-templates>
                        </xsl:when>
                        <xsl:otherwise>
                            <fo:inline font-family="{$ftSFBdObl}">
                                <xsl:text>Anmerkungsreferenz in Band </xsl:text>
                                <xsl:value-of select="$targetDocVolume"/>
                                <xsl:text> nicht gefunden</xsl:text>
                            </fo:inline>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </fo:inline>
    </xsl:template>


    <xsl:template match="tei:note" mode="anmerkungsreferenz_gesamt">
        <xsl:param name="targetDocID"/>
        <xsl:param name="referingDocID"/>

        <xsl:variable name="targetDocBodyID" select="concat('body_', $targetDocID)"/>
        <xsl:variable name="volumeText" select="hiko:getVolumeText($targetDocID)"/>
        <xsl:variable name="docText" select="hiko:getDocTextGesamt($targetDocID, $referingDocID)"/>

        <xsl:value-of select="$volumeText"/>
        <xsl:value-of select="$docText"/>

        <!-- Wenn der Verweis auf eine Fußnote im selben Protokoll geht -> Leerzeichen vor dem Anmerkungstext weglassen -->
        <xsl:if test="not(empty($docText))">
            <xsl:text> </xsl:text>
        </xsl:if>
        <xsl:text>Anm.&#xa0;</xsl:text>
        <xsl:value-of select="count(preceding::tei:note[not(@type) and ancestor::tei:body[@xml:id = $targetDocBodyID]]) + 1"/>
    </xsl:template>

    <xsl:function name="hiko:getDocTextGesamt">
        <xsl:param name="targetDocID"/>
        <xsl:param name="referingDocID"/>

        <xsl:choose>
            <xsl:when test="$targetDocID != $referingDocID">
                <!--Fallunterscheidung Protokolle/Editionsabschnitte-->
                <xsl:variable name="documentType" select="substring($targetDocID, 6, 1)"/>

                <xsl:choose>
                    <xsl:when test="$documentType = 'a'">
                        <xsl:variable name="targetDocAbrev" select="substring($targetDocID, 7, 4)"/>

                        <xsl:choose>
                            <xsl:when test="$targetDocAbrev = 'EDGS'">
                                <fo:inline>Editionsgrundsätze </fo:inline>
                            </xsl:when>
                            <xsl:when test="$targetDocAbrev = 'ENLT'">
                                <fo:inline>Einleitung </fo:inline>
                            </xsl:when>
                            <xsl:otherwise>
                                <fo:inline font-family="{$ftSFBdObl}">UNBEKANNTER EDITIONSABSCHNITT</fo:inline>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>

                    <xsl:when test="$documentType = 'p'">
                        <xsl:variable name="targetDocNum" select="substring($targetDocID, 7, 3)"/>
                        <xsl:variable name="targetDocNumWithLeadingZeros"
                            select="substring(concat('000', $targetDocNum), string-length($targetDocNum) + 1, 3)"/>
                        <fo:inline>Nr. <xsl:value-of select="$targetDocNumWithLeadingZeros"/></fo:inline>
                    </xsl:when>

                    <xsl:otherwise>
                        <fo:inline font-family="{$ftSFBdObl}">UNBEKANNTER DOKUMENTTYP</fo:inline>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
        </xsl:choose>
    </xsl:function>



    <!-- - - - - - - - - - -    UNGEDRUCKTE QUELLEN - - - - - - - - - - -->
    <xsl:template match="tei:body[@xml:id = 'body_UGQ']">
        <fo:block id="{generate-id()}" line-height="115%" font-size="{$ftsz_einspaltRegister}">
            <fo:marker marker-class-name="registertitel">Ungedruckte Quellen</fo:marker>
            <fo:block font-size="{$ftsz_Überschrift_Abschnitt}" font-family="{$ftSfBd}" text-align="center" space-after="7mm" id="RDB_QLI"
                >Quellen- und Literaturverzeichnis</fo:block>
            <fo:block font-size="{$ftsz_Überschrift_Abschnitt}" text-align="center" space-after="8mm" id="RDB_UGQ">Ungedruckte
                Quellen</fo:block>
            <xsl:apply-templates select="./tei:list[@type = 'Archive']"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:list[@type = 'Archive']">
        <xsl:apply-templates select="./tei:item" mode="Archiv"/>
    </xsl:template>

    <xsl:template match="tei:item" mode="Archiv">
        <xsl:variable name="archivTitel">
            <xsl:value-of select="hiko:getSourceCollectionTitle(.)"/>
        </xsl:variable>

        <fo:block text-align="justify">
            <fo:block font-family="{$ftSfBd}" space-before="6mm" space-after="3mm">
                <xsl:value-of select="$archivTitel"/>
            </fo:block>
            <xsl:apply-templates select="./tei:list[@type = 'Bestände']"/>
            <xsl:apply-templates select="./tei:list[@type = 'Quellen']"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:list[@type = 'Bestände']">
        <fo:block font-family="{$ftSf}">
            <xsl:apply-templates select="./tei:item" mode="Bestand"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:item" mode="Bestand">
        <xsl:variable name="bestandTitel">
            <xsl:value-of select="hiko:getSourceCollectionTitle(.)"/>
        </xsl:variable>
        <fo:block space-before="3mm">
            <xsl:value-of select="$bestandTitel"/>
        </fo:block>
        <xsl:apply-templates select="./tei:list[@type = 'Quellen']"/>
    </xsl:template>

    <xsl:template match="tei:list[@type = 'Quellen']">
        <fo:block font-weight="normal" margin-left="4mm">
            <xsl:apply-templates select="./tei:item" mode="quelle"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:item[position() != last()]" mode="quelle">
        <fo:inline>
            <xsl:value-of select="normalize-space(.)"/>, </fo:inline>
    </xsl:template>

    <xsl:template match="tei:item[position() = last()]" mode="quelle">
        <fo:inline>
            <xsl:value-of select="normalize-space(.)"/>
        </fo:inline>
    </xsl:template>


    <!-- - - - - - - - - - -    GEDRUCKTE QUELLEN UND LITERATUR - - - - - - - - - - -->
    <xsl:template match="tei:body[@xml:id = 'body_GQL']">
        <fo:marker marker-class-name="registertitel">Gedruckte Quellen und Literatur</fo:marker>
        <fo:block font-size="{$ftsz_Überschrift_Abschnitt}" text-align="center" space-after="10mm" id="RDB_GQL">Gedruckte Quellen und
            Literatur</fo:block>
        <xsl:apply-templates select="//tei:bibl" mode="literatur"/>
    </xsl:template>
    <xsl:template match="tei:bibl" mode="literatur">
        <xsl:variable name="id">
            <xsl:value-of select="@xml:id"/>
        </xsl:variable>

        <xsl:if test="preceding::tei:bibl[@corresp = $id]">
            <fo:block start-indent="3mm" text-indent="-3mm" text-align="justify" line-height="115%" font-size="{$ftsz_einspaltRegister}">
                <xsl:apply-templates select="./tei:title[@type = 'Volltitel']" mode="literatur"/>
            </fo:block>
        </xsl:if>
    </xsl:template>

    <xsl:template match="tei:seg[@type = 'Kennabschnitt']" mode="literatur">
        <fo:inline font-family="{$ftSfObl}">
            <xsl:apply-templates mode="literatur"/>
        </fo:inline>
    </xsl:template>
    <xsl:template match="tei:seg[@type = 'Kennabschnitt']" mode="gleicherAutor">
        <xsl:text>– </xsl:text>
    </xsl:template>

    <xsl:template match="tei:seg" mode="literatur">
        <fo:inline>
            <xsl:apply-templates mode="literatur"/>
        </fo:inline>
    </xsl:template>


    <!-- - - - - - - - - - -    PERSONENREGISTER    - - - - - - - - - - -->
    <xsl:template match="tei:body[@xml:id = 'body_PER']">
        <fo:marker marker-class-name="registertitel">Personenregister</fo:marker>
        <fo:block id="RDB_PER" font-size="{$ftsz_Überschrift_Abschnitt}" font-family="{$ftSfBd}" text-align="center" space-after="5mm"
            span="all">Personenregister</fo:block>
        <fo:block font-size="{$ftsz_Erläuterungstext}" text-align="justify" margin-bottom="4mm" span="all" line-height="105%">
            <xsl:apply-templates select="following::tei:div[@xml:id = 'psrg_erl']"/>
        </fo:block>
        <xsl:apply-templates select="//tei:listPerson/tei:person" mode="person"/>

    </xsl:template>

    <xsl:template match="tei:person" mode="person">
        <xsl:variable name="id">
            <xsl:value-of select="@xml:id"/>
        </xsl:variable>

        <!-- Nur Einträge aus der RDB übernehmen, die im Editionstext referenziert werden -->
        <xsl:choose>
            <xsl:when test="./tei:note[@type = 'Querverweis']">
                <xsl:variable name="target">
                    <xsl:value-of select="./tei:note[@type = 'Querverweis']/@target"/>
                </xsl:variable>

                <xsl:if
                    test="preceding::tei:rs[(@type = 'Person' or @type = 'Sprecher' or @type = 'Unterzeichner') and @key = $target and not(ancestor::tei:body[@xml:id = 'body_PER'])] | preceding::tei:note[@type = 'Biogramm' and @target = $target] | preceding::tei:ref[@type = 'Biogramm_Platzhalter' and @target = $target]">
                    <fo:block start-indent="3mm" text-indent="-3mm" font-size="{$ftsz_Fließtext}" line-height="105%">
                        <fo:inline>
                            <xsl:value-of select="./tei:persName[@type = 'Registername']"/>
                        </fo:inline>
                    </fo:block>
                </xsl:if>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if
                    test="preceding::tei:rs[(@type = 'Person' or @type = 'Sprecher' or @type = 'Unterzeichner') and @key = $id and not(ancestor::tei:body[@xml:id = 'body_PER'])] | preceding::tei:note[@type = 'Biogramm' and @target = $id] | preceding::tei:ref[@type = 'Biogramm_Platzhalter' and @target = $id]">
                    <fo:block start-indent="3mm" text-indent="-3mm" font-size="{$ftsz_zweispaltRegister}" line-height="105%">
                        <fo:inline>
                            <xsl:value-of select="./tei:persName[@type = 'Registername']"/>
                        </fo:inline>
                        <xsl:if test="not(empty(./tei:note[@type = 'Qualifikator']/text()))">
                            <fo:inline>, <xsl:value-of select="./tei:note[@type = 'Qualifikator']"/></fo:inline>
                        </xsl:if>
                        <fo:inline>&#xa0;##&#xa0;</fo:inline>
                        <xsl:for-each
                            select="preceding::tei:rs[(@type = 'Person' or @type = 'Sprecher' or @type = 'Unterzeichner') and @key = $id and not(ancestor::tei:body[@xml:id = 'body_PER'])] | preceding::tei:note[@type = 'Biogramm' and @target = $id] | preceding::tei:ref[@type = 'Biogramm_Platzhalter' and @target = $id]">
                            <fo:inline>
                                <xsl:choose>
                                    <xsl:when test="position() = 1">
                                        <xsl:text/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>, </xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <fo:page-number-citation ref-id="{generate-id()}"/>
                                <xsl:if test=".[local-name() = 'note'] or .[local-name() = 'ref']">
                                    <xsl:text>*</xsl:text>
                                </xsl:if>
                            </fo:inline>
                        </xsl:for-each>
                        <xsl:text> @</xsl:text>
                    </fo:block>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- - - - - - - - - - -    SACHREGISTER    - - - - - - - - - -  -->
    <xsl:template match="tei:body[@xml:id = 'body_SSW']">
        <fo:marker marker-class-name="registertitel">Orts- und Sachregister</fo:marker>
        <fo:block id="RDB_SSW" font-size="{$ftsz_Überschrift_Abschnitt}" font-family="{$ftSfBd}" text-align="center" margin-bottom="5mm"
            span="all">Orts- und Sachregister</fo:block>
        <fo:block font-size="{$ftsz_Erläuterungstext}" text-align="justify" margin-bottom="4mm" span="all" line-height="105%">
            <xsl:apply-templates select="following::tei:div[@xml:id = 'osrg_erl']"/>
        </fo:block>
        <fo:block>
            <xsl:apply-templates select="./tei:list/tei:item" mode="sache"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:item" mode="sache">

        <xsl:variable name="id">
            <xsl:value-of select="@xml:id"/>
        </xsl:variable>

        <xsl:variable name="geo">
            <xsl:value-of select="@corresp"/>
        </xsl:variable>

        <xsl:variable name="ebene">
            <xsl:value-of select="parent::tei:list/@n"/>
        </xsl:variable>

        <!-- Einträge auf oberster Ebene werden eingerückt wie Einträge auf zweiter Ebene-->
        <xsl:variable name="einrueckEbene">
            <xsl:choose>
                <xsl:when test="$ebene = 0"> 1 </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$ebene"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <!-- Nur Einträge ins gedruckte Register übernehmen, die untergeordnete Einträge oder Querverweise beinhalten oder die selbst im Editionstext referenziert werden
                 -->
        <xsl:if
            test="
                .[child::tei:list or tei:ref] |
                preceding::tei:rs[@type = 'Sachschlagwort' and @key = $id and not(ancestor::tei:body[@xml:id = 'body_PER'])]
                | preceding::tei:rs[@type = 'Ort' and @key = $geo and not(ancestor::tei:body[@xml:id = 'body_PER'])]
                | preceding::tei:index[@indexName = 'Sachschlagwörter' and @corresp = $id and not(ancestor::tei:body[@xml:id = 'body_PER'])]">
            <fo:block start-indent="{$einrueckEbene} *2.5mm" text-indent="{$einrueckEbene} * -2.5mm" font-size="{$ftsz_zweispaltRegister}"
                line-height="105%">

                <xsl:choose>
                    <xsl:when test="parent::tei:list[@n = 3]">
                        <fo:inline>–&#xa0;–&#xa0;–&#8196;</fo:inline>
                    </xsl:when>
                    <xsl:when test="parent::tei:list[@n = 2]">
                        <fo:inline>–&#xa0;–&#8196;</fo:inline>
                    </xsl:when>
                    <xsl:when test="parent::tei:list[@n = 1]">
                        <fo:inline>–&#8196;</fo:inline>
                    </xsl:when>
                </xsl:choose>

                <fo:inline>
                    <xsl:value-of select="./tei:term"/>
                </fo:inline>

                <fo:inline>&#xa0;##&#xa0;</fo:inline>
                <xsl:for-each
                    select="
                        preceding::tei:rs[@type = 'Sachschlagwort' and @key = $id and not(ancestor::tei:body[@xml:id = 'body_PER'])]
                        | preceding::tei:rs[@type = 'Ort' and @key = $geo and not(ancestor::tei:body[@xml:id = 'body_PER'])]
                        | preceding::tei:index[@indexName = 'Sachschlagwörter' and @corresp = $id and not(ancestor::tei:body[@xml:id = 'body_PER'])]">
                    <fo:inline>
                        <xsl:choose>
                            <xsl:when test="position() = 1">
                                <xsl:text/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>, </xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>


                        <xsl:choose>
                            <xsl:when test="./local-name() = 'index'">
                                <xsl:variable name="spanTo">
                                    <xsl:value-of select="./@spanTo"/>
                                </xsl:variable>
                                <xsl:variable name="spanTo_shortened" select="substring($spanTo, 2)"/>
                                <fo:page-number-citation ref-id="{generate-id()}"/>
                                <xsl:text>–</xsl:text>
                                <xsl:apply-templates select="//tei:anchor[@xml:id = $spanTo_shortened]" mode="embedded"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <fo:page-number-citation ref-id="{generate-id()}"/>
                                <xsl:if test=".[@subtype = 'Gesetzfundstelle']">
                                    <xsl:text>*</xsl:text>
                                </xsl:if>
                            </xsl:otherwise>
                        </xsl:choose>
                    </fo:inline>
                </xsl:for-each>
                <xsl:text>@</xsl:text>

                <xsl:apply-templates select="./tei:list/tei:item" mode="sache"/>
                <xsl:if test="./tei:ref">

                    <xsl:choose>
                        <xsl:when test="./tei:list[@type = 'Sachschlagwörter']">
                            <fo:block>
                                <xsl:for-each select="ancestor::tei:list">
                                    <fo:inline>–&#xa0;</fo:inline>
                                </xsl:for-each>
                                <fo:inline>s.&#xa0;a. </fo:inline>
                                <xsl:apply-templates select="./tei:ref[@type = 'Querverweis']"/>
                            </fo:block>
                        </xsl:when>
                        <xsl:otherwise>
                            <fo:inline> s. </fo:inline>
                            <xsl:apply-templates select="./tei:ref[@type = 'Querverweis']"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:if>
            </fo:block>
        </xsl:if>
    </xsl:template>

    <xsl:template match="tei:anchor" mode="embedded">
        <fo:inline>
            <fo:page-number-citation ref-id="{generate-id()}"/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:ref[@type = 'Querverweis']">
        <xsl:variable name="refId">
            <xsl:value-of select="@target"/>
        </xsl:variable>
        <xsl:variable name="refTerm">
            <xsl:value-of select="//tei:item[@xml:id = $refId]/tei:term"/>
        </xsl:variable>

        <!--Prüfen ob noch weitere Querverweise folgen -->
        <xsl:choose>
            <xsl:when test="following-sibling::tei:ref">
                <fo:inline>
                    <xsl:value-of select="$refTerm"/>
                    <xsl:text>, </xsl:text>
                </fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline>
                    <xsl:value-of select="$refTerm"/>
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- - - - - - - - - - -    DRUCKREGISTER    - - - - - - - - - -  -->
    <xsl:template match="tei:body[@xml:id = 'body_PSRG' or @xml:id = 'body_OSRG']">

        <xsl:variable name="registername">
            <xsl:choose>
                <xsl:when test="@xml:id = 'body_PSRG'">
                    <xsl:value-of select="'Personenregister'"/>
                </xsl:when>
                <xsl:when test="@xml:id = 'body_OSRG'">
                    <xsl:value-of select="'Orts- und Sachregister'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'DRUCKREGISTER'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <xsl:variable name="id">
            <xsl:choose>
                <xsl:when test="@xml:id = 'body_PSRG'">
                    <xsl:value-of select="'RDB_PER'"/>
                </xsl:when>
                <xsl:when test="@xml:id = 'body_OSRG'">
                    <xsl:value-of select="'RDB_SSW'"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>

        <fo:marker marker-class-name="registertitel">
            <xsl:value-of select="$registername"/>
        </fo:marker>
        <fo:block id="{$id}" font-size="{$ftsz_Überschrift_Abschnitt}" font-family="{$ftSfBd}" text-align="center" margin-bottom="3.5mm"
            span="all">
            <xsl:value-of select="$registername"/>
        </fo:block>

        <xsl:apply-templates select=".//tei:p[@rend = 'vortext']" mode="vortext"/>

        <fo:block>
            <xsl:apply-templates select="./tei:list" mode="druckregister"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:list" mode="druckregister">
        <xsl:variable name="ebene">
            <xsl:value-of select="@n"/>
        </xsl:variable>

        <!-- Einträge auf oberster Ebene werden eingerückt wie Einträge auf zweiter Ebene-->
        <xsl:variable name="einrueckEbene">
            <xsl:choose>
                <xsl:when test="$ebene = 0">
                    <xsl:value-of select="'1'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$ebene"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <xsl:variable name="margin-top">
            <xsl:choose>
                <xsl:when test="./@rend = 'lettergap'">
                    <xsl:value-of select="'1.05em'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'0'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:block start-indent="{$einrueckEbene} *2.4mm" text-indent="{$einrueckEbene} * -2.4mm" font-size="{$ftsz_zweispaltRegister}"
            line-height="105%" margin-top="{$margin-top}" page-break-inside="auto" orphans="1" widows="2" text-align="left">
            <fo:inline>
                <xsl:apply-templates/>
            </fo:inline>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:p" mode="vortext">
        <fo:block font-size="{$ftsz_Erläuterungstext}" text-align="justify" margin-bottom="4mm" span="all" line-height="105%">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>


    <!-- - - - - - - - - - -    TEMPLATES FÜR INHALTSVERZEICHNIS    - - - - - - - - - -->
    <xsl:template name="ivz.enlt">
        <xsl:variable name="abschnittsname">
            <xsl:choose>
                <xsl:when test="tei:front/tei:head">
                    <xsl:value-of select="tei:front/tei:head"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="@n"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:block text-align-last="justify">
            <fo:table width="120mm">
                <fo:table-column column-number="1" column-width="117mm"/>
                <fo:table-body>
                    <fo:table-row>
                        <fo:table-cell column-number="1">
                            <fo:block>
                                <xsl:value-of select="$abschnittsname"/>
                                <fo:inline>
                                    <fo:leader leader-pattern="dots"/>
                                </fo:inline>
                                <fo:page-number-citation ref-id="{generate-id()}"/>
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <xsl:for-each select=".//tei:div[@type = 'Unterabschnitt']">
                        <xsl:call-template name="ivz.unterabschnitt"/>
                    </xsl:for-each>
                    <fo:table-row>
                        <fo:table-cell>
                            <fo:block>&#xa0;</fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </fo:table-body>
            </fo:table>
        </fo:block>
    </xsl:template>

    <xsl:template name="ivz.unterabschnitt">
        <xsl:variable name="nummer" select="./tei:head/tei:num/text()"/>
        <xsl:variable name="ueberschrift" select="./tei:head/text()"/>
        <fo:table-row text-align="justify" height="1.3em">
            <fo:table-cell column-number="1" width="112mm" padding-start="5mm">
                <fo:table>
                    <fo:table-column column-number="1" column-width="5mm" text-align="right"/>
                    <fo:table-column column-number="2" padding-start="1mm"/>
                    <fo:table-body>
                        <fo:table-row>
                            <fo:table-cell column-number="1">
                                <fo:block text-align="right">
                                    <xsl:value-of select="$nummer"/>
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell column-number="2">
                                <fo:block text-align="justify">
                                    <xsl:value-of select="$ueberschrift"/>
                                    <fo:leader leader-pattern="dots"/>
                                    <fo:page-number-citation ref-id="{generate-id()}"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </fo:table-body>
                </fo:table>
            </fo:table-cell>
        </fo:table-row>
        <xsl:for-each select=".//tei:div[@type = 'Textunterpunkt']">
            <xsl:call-template name="ivz.textunterpunkt"/>
        </xsl:for-each>
    </xsl:template>

    <xsl:template name="ivz.textunterpunkt">
        <xsl:variable name="nummer" select="./tei:head/tei:num/text()"/>
        <xsl:variable name="ueberschrift" select="./tei:head/text()"/>
        <fo:table-row text-align="justify" height="1.3em">
            <fo:table-cell column-number="1" width="107mm" padding-start="10mm">
                <fo:table>
                    <fo:table-column column-number="1" column-width="5mm" text-align="right"/>
                    <fo:table-column column-number="2" padding-start="1mm"/>
                    <fo:table-body>
                        <fo:table-row>
                            <fo:table-cell column-number="1">
                                <fo:block text-align="right">
                                    <xsl:value-of select="$nummer"/>
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell column-number="2">
                                <fo:block text-align="justify">
                                    <xsl:value-of select="$ueberschrift"/>
                                    <fo:leader leader-pattern="dots"/>
                                    <fo:page-number-citation ref-id="{generate-id()}"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </fo:table-body>
                </fo:table>
            </fo:table-cell>
        </fo:table-row>
    </xsl:template>

    <xsl:template name="ivz.zeile">
        <xsl:variable name="abschnittsname">
            <xsl:choose>
                <xsl:when test="tei:front/tei:head">
                    <xsl:value-of select="tei:front/tei:head"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="@n"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:block text-align-last="justify">
            <fo:table width="120mm">
                <fo:table-column column-number="1" column-width="117mm"/>
                <fo:table-body>
                    <fo:table-row>
                        <fo:table-cell column-number="1">
                            <fo:block>
                                <xsl:value-of select="$abschnittsname"/>
                                <fo:inline>
                                    <fo:leader leader-pattern="dots"/>
                                </fo:inline>
                                <fo:page-number-citation ref-id="{generate-id()}"/>
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row>
                        <fo:table-cell>
                            <fo:block>&#xa0;</fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </fo:table-body>
            </fo:table>
        </fo:block>
    </xsl:template>

    <xsl:template name="ivz.osrg">
        <fo:block text-align-last="justify">
            <fo:table width="120mm">
                <fo:table-column column-number="1" column-width="117mm"/>
                <fo:table-body>
                    <fo:table-row>
                        <fo:table-cell column-number="1">
                            <fo:block>
                                <xsl:value-of select="'Orts- und Sachregister'"/>
                                <fo:inline>
                                    <fo:leader leader-pattern="dots"/>
                                </fo:inline>
                                <fo:page-number-citation ref-id="RDB_SSW"/>
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row>
                        <fo:table-cell>
                            <fo:block>&#xa0;</fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </fo:table-body>
            </fo:table>
        </fo:block>
    </xsl:template>

    <xsl:template name="ivz.psrg">
        <fo:block text-align-last="justify">
            <fo:table width="120mm">
                <fo:table-column column-number="1" column-width="117mm"/>
                <fo:table-body>
                    <fo:table-row>
                        <fo:table-cell column-number="1">
                            <fo:block>
                                <xsl:value-of select="'Personenregister'"/>
                                <fo:inline>
                                    <fo:leader leader-pattern="dots"/>
                                </fo:inline>
                                <fo:page-number-citation ref-id="RDB_PER"/>
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row>
                        <fo:table-cell>
                            <fo:block>&#xa0;</fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </fo:table-body>
            </fo:table>
        </fo:block>
    </xsl:template>


    <!-- - - - - - - - - - -    FUNKTIONEN  - - - - - - - - - - -->
    <xsl:function name="hiko:getSourceCollectionTitle">
        <xsl:param name="node"/>
        <xsl:choose>
            <xsl:when test="$node/tei:name[@type = 'Vollname']">
                <xsl:value-of select="$node/tei:name[@type = 'Vollname']"/> (<xsl:value-of select="$node/tei:name[@type = 'Kennname']"/>) </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$node/tei:name[@type = 'Kennname']"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>

</xsl:stylesheet>
