<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:my="http://zeromat.org" version="2.0">


    <!--Kein Indent wegen Leerzeichen -->
    <xsl:output method="xml" version="1.0" indent="no"/>
    <xsl:preserve-space elements="*"/>

    <!-- - - - - - - - - - -    SCHRIFTARTEN    - - - - - - - - - - -->
    <xsl:variable name="ftSf" select="'AGaramondPHK-Regular'"/>
    <xsl:variable name="ftSfObl" select="'AGaramondPHK-Italic'"/>
    <xsl:variable name="ftSfBd" select="'AGaramondPHK-Bold'"/>
    <xsl:variable name="ftSFBdObl" select="'AGaramondPHK-BoldItalic'"/>

    <!-- - - - - - - - - - -    PARAMETER    - - - - - - - - - - -->
    <xsl:param name="PER" select="''"/>
    <xsl:variable name="per" select="document($PER)"/>
    <xsl:param name="SSW" select="''"/>
    <xsl:variable name="ssw" select="document($SSW)"/>
    <xsl:param name="ORT" select="''"/>
    <xsl:variable name="ort" select="document($ORT)"/>
    <xsl:param name="GQL" select="''"/>
    <xsl:variable name="gql" select="document($GQL)"/>
    <xsl:param name="UGQ" select="''"/>
    <xsl:variable name="ugq" select="document($UGQ)"/>

    <!-- - - - - - - - - - -    STATISCHE VARIABLEN - - - - - - - - - - -->
    <xsl:param name="heute">
        <xsl:value-of select="format-date(current-date(), '[D01].[M01].[Y0001]')"/>
    </xsl:param>
    
    <xsl:variable name="dokid" select="@xml:id"/>

    <!-- - - - - - - - - - -    BASIS   - - - - - - - - - - -->
    <xsl:template match="tei:TEI">

        <fo:root font-size="11pt" font-family="{$ftSf}" line-height="1.3em" xml:lang="de" hyphenate="true" line-height-shift-adjustment="disregard-shifts" hyphenation-push-character-count="4" hyphenation-remain-character-count="4">
            <!--Seite einrichten-->
            <fo:layout-master-set>
                <fo:simple-page-master master-name="standard-seite" page-height="297mm" page-width="210mm" margin="20mm">
                    <fo:region-body margin-top=".5in" margin-bottom="0.7in"/>
                    <fo:region-after extent=".5in" region-name="xsl-region-after"/>
                </fo:simple-page-master>
            </fo:layout-master-set>

            <fo:page-sequence master-reference="standard-seite">

                <!-- Fußzeile -->
                <fo:static-content flow-name="xsl-region-after">
                    <fo:table table-layout="fixed" width="170mm" space-before="0pt" space-after="0pt" border-top="1px solid black" color="#336699">
                        <fo:table-column column-width="30mm" text-align="left"/>
                        <fo:table-column column-width="110mm" text-align="center"/>
                        <fo:table-column column-width="30mm" text-align="end"/>
                        <fo:table-body>
                            <fo:table-row>
                                <fo:table-cell>
                                    <fo:block>
                                        <xsl:value-of select="$heute"/>
                                    </fo:block>
                                </fo:table-cell>
                                <fo:table-cell>
                                    <fo:block>
                                        <xsl:value-of select="$dokid"/>
                                    </fo:block>
                                </fo:table-cell>
                                <fo:table-cell text-align="end">
                                    <fo:block>
                                        <fo:page-number/>
                                    </fo:block>
                                </fo:table-cell>
                            </fo:table-row>
                        </fo:table-body>
                    </fo:table>
                </fo:static-content>


                <!--Hauptteil-->
                <fo:flow flow-name="xsl-region-body">

                    <!--Titelzeile-->
                    <fo:block font-family="{$ftSfBd}" font-size="14pt" font-weight="bold" space-after="15pt" text-align="center" keep-with-next="1">
                        <xsl:text>Registerdatenbank Ministerratsprotokolle 1945-1962</xsl:text>
                    </fo:block>

                    <fo:block font-family="{$ftSfBd}" font-size="14pt" font-weight="bold" space-after="15pt" text-align="center" keep-with-next="1">
                        <xsl:value-of select="//tei:teiHeader//tei:title[@type = 'Registername']"/>
                    </fo:block>
                    <xsl:apply-templates select="./tei:text"/>
                    
                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>

    <!-- - - - - - - - - -  GQL - - - - - - - - - - -->
    <xsl:template match="tei:listBibl[@type = 'Literatur']/tei:bibl">

        <fo:block space-before="6pt">
            <xsl:apply-templates select="tei:title[@type = 'Volltitel']"/>
            <fo:inline font-weight="bold"> [Zit. als: </fo:inline>
            <xsl:apply-templates select="tei:title[@type = 'Kurztitel']"/>
            <xsl:text>]</xsl:text>
        </fo:block>
    </xsl:template>


    <xsl:template match="tei:seg[@type = 'Kennabschnitt']">
        <fo:inline font-style="oblique">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:title[@type = 'Kurztitel']">
        <fo:inline font-weight="bold">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:seg">
        <fo:inline>
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>


    <!-- - - - - - - - - - -    ZTG - - - - - - - - - - -->
    <xsl:template match="tei:listBibl[@type = 'Zeitungen']/tei:bibl">
        <fo:block space-before="6pt">
            <xsl:apply-templates select="tei:title[@type = 'Haupttitel']"/>
            <xsl:if test="child::tei:title[@type = 'Kürzel'] != ''">
                <fo:inline> (</fo:inline>
                <xsl:apply-templates select="tei:title[@type = 'Kürzel']"/>
                <fo:inline>)</fo:inline>
            </xsl:if>
            <!--Zusatz anzeigen, falls vorhanden, mit trennendem Punkt-->
            <xsl:if test="child::tei:title[@type = 'Zusatz'] != ''">
                <fo:inline>. </fo:inline>
                <xsl:apply-templates select="tei:title[@type = 'Zusatz']"/>
            </xsl:if>
        </fo:block>
    </xsl:template>

    <!-- - - - - - - - - - -    UGQ - - - - - - - - - - -->
    <!--Archive-->
    <xsl:template match="tei:list[@type = 'Archive']">
        <fo:block>
            <xsl:apply-templates select="child::tei:item" mode="Archiv"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:item" mode="Archiv">
        <fo:block font-weight="bold" space-before="11pt">
            <xsl:choose>
                <xsl:when test="./tei:name[@type = 'Vollname']">
                    <xsl:apply-templates select="child::tei:name[@type = 'Vollname']"/>
                    <xsl:text> (</xsl:text>
                    <xsl:apply-templates select="child::tei:name[@type = 'Kennname']"/>
                    <xsl:text>)</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="child::tei:name[@type = 'Kennname']"/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:block>
        <xsl:apply-templates select="child::tei:list[@type = 'Bestände']"/>
        <xsl:apply-templates select="child::tei:list[@type = 'Quellen']"/>
    </xsl:template>

    <!--Bestände-->
    <xsl:template match="tei:list[@type = 'Bestände']">
        <fo:block>
            <xsl:apply-templates select="child::tei:item" mode="Bestand"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:item" mode="Bestand">
        <fo:block space-before="7pt">
            <xsl:choose>
                <xsl:when test="./tei:name[@type = 'Vollname']">
                    <xsl:apply-templates select="child::tei:name[@type = 'Vollname']"/>
                    <xsl:text> (</xsl:text>
                    <xsl:apply-templates select="child::tei:name[@type = 'Kennname']"/>
                    <xsl:text>)</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="child::tei:name[@type = 'Kennname']"/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:block>
        <fo:block>
            <xsl:apply-templates select="child::tei:list[@type = 'Quellen']"/>
        </fo:block>
    </xsl:template>

    <!--Quellen-->
    <xsl:template match="tei:list[@type = 'Quellen']">
        <fo:block margin-left="8pt">
            <xsl:apply-templates select="child::tei:item" mode="Quelle"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:item[position() != last()]" mode="Quelle">
        <fo:inline>
            <xsl:value-of select="normalize-space(.)"/>, </fo:inline>

    </xsl:template>

    <xsl:template match="tei:item[position() = last()]" mode="Quelle">
        <fo:inline>
            <xsl:value-of select="normalize-space(.)"/>
        </fo:inline>
    </xsl:template>

    <!-- - - - - - - - - - -    SSW - - - - - - - - - - -->
    <xsl:template match="tei:list[@type = 'Sachschlagwörter']">
        <fo:block>
            <xsl:apply-templates select="child::tei:item" mode="Sachschlagwort"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:item" mode="Sachschlagwort">
        <xsl:variable name="ebene">
            <xsl:value-of select="parent::tei:list/@n"/>
        </xsl:variable>


        <fo:block start-indent="{$ebene}*1.5em" text-indent="-{$ebene}*0.6em">
            <!--Einrückung geschachtelter Schlagwörter-->
            <xsl:for-each select="ancestor::tei:list[@n > 0]">
                <xsl:text>- </xsl:text>
            </xsl:for-each>

            <xsl:apply-templates select="child::tei:term"/>

            <xsl:if test="./@corresp">
                <fo:inline font-style="oblique" font-size="9pt"> (Geoverweis: <xsl:value-of select="./@corresp"/>)</fo:inline>
            </xsl:if>
            <xsl:apply-templates select="child::tei:list[@type = 'Sachschlagwörter']"/>

            <!-- Querverweise -->
            <xsl:if test="child::tei:ref">
                <xsl:choose>
                    <xsl:when test="child::tei:list[@type = 'Sachschlagwörter']">
                        <fo:block>
                            <xsl:for-each select="ancestor::tei:list">
                                <fo:inline>- </fo:inline>
                            </xsl:for-each>
                            <fo:inline> s. auch </fo:inline>
                            <xsl:apply-templates select="child::tei:ref[@type = 'Querverweis']"/>
                        </fo:block>
                    </xsl:when>
                    <xsl:otherwise>
                        <fo:inline> s. </fo:inline>
                        <xsl:apply-templates select="child::tei:ref[@type = 'Querverweis']"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:ref[@type = 'Querverweis']">
        <xsl:variable name="refId">
            <xsl:value-of select="./@target"/>
        </xsl:variable>
        <xsl:variable name="refTerm">
            <xsl:value-of select="//tei:item[@xml:id = $refId]/tei:term"/>
        </xsl:variable>

        <xsl:choose>
            <xsl:when test="following-sibling::tei:ref">
                <fo:inline>
                    <xsl:value-of select="$refTerm"/>
                    <xsl:text>, </xsl:text>
                </fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline>
                    <xsl:value-of select="$refTerm"/>
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- - - - - - - - - - -    PER - - - - - - - - - - -->
    <xsl:template match="tei:person">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:persName[@type = 'Registername']">
        <fo:block font-family="{$ftSfBd}" font-size="14pt" font-weight="bold" space-before="15pt" text-align="left" keep-with-next="1">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:persName[@type = 'Lesename']">
        <fo:block>
            <fo:inline font-weight="bold">Lesename: </fo:inline>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:note[@type = 'Qualifikator']">
        <fo:block>
            <fo:inline font-weight="bold">Qualifikator: </fo:inline>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:note[@type = 'Biogramm']">
        <fo:block>
            <fo:inline font-weight="bold">Biogramm: </fo:inline>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:name[@type = 'Hervorhebung']">
        <fo:inline font-style="oblique">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:foreign">
        <fo:inline font-style="oblique">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:idno[@type = 'db']">
        <xsl:if test=". ne ''">
            <fo:block>
                <fo:inline text-decoration="underline" font-style="oblique">
                    <xsl:text>https://www.deutsche-biographie.de/</xsl:text>
                    <xsl:value-of select="."/>
                    <xsl:text>.html</xsl:text>
                </fo:inline>
            </fo:block>
        </xsl:if>
    </xsl:template>

    <xsl:template match="tei:idno[@type = 'gnd']">
        <xsl:if test=". ne ''">
            <fo:block>
                <fo:inline text-decoration="underline" font-style="oblique">
                    <xsl:text>https://www.deutsche-biographie.de/pnd</xsl:text>
                    <xsl:value-of select="."/>
                    <xsl:text>.html</xsl:text>
                </fo:inline>
            </fo:block>
        </xsl:if>
    </xsl:template>

    <!-- - - - - - - - - - -    ORT - - - - - - - - - - -->
    <xsl:template match="tei:listPlace/tei:place">
        <fo:block space-after="3pt">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:listPlace/tei:place/tei:placeName">
        <fo:block font-family="{$ftSfBd}" font-size="14pt" font-weight="bold" space-before="15pt" text-align="left" keep-with-next="1">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:location">
        <fo:block>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
    <xsl:template match="tei:geo">
        <fo:inline font-style="oblique">Geokoordinaten(<xsl:value-of select="parent::tei:location/@type"/>) : </fo:inline>
        <fo:inline>
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <!-- - - - - - - - - - -   ABSATZ  - - - - - - - - - - -->
    <xsl:template match="tei:p">

        <!--Spezielle Ausrichtung -->
        <xsl:choose>
            <xsl:when test=".[@rend]">
                <xsl:variable name="alignment">
                    <xsl:choose>
                        <xsl:when test="@rend">
                            <xsl:choose>
                                <xsl:when test="@rend = 'aligncenter'">
                                    <xsl:text>center</xsl:text>
                                </xsl:when>
                                <xsl:when test="@rend = 'alignright'">
                                    <xsl:text>end</xsl:text>
                                </xsl:when>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>justify</xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>

                <fo:block text-align="{$alignment}" line-height="1.3em">
                    <xsl:apply-templates/>
                </fo:block>
            </xsl:when>

            <!-- ...oder normaler Blocksatz mit Einzug -->
            <xsl:otherwise>

                <!--Einzug außer beim ersten Absatz eine Tagesordnungspunktes-->
                <xsl:choose>
                    <xsl:when test=".[parent::tei:div[@type = 'Top'] and preceding-sibling::*[1][local-name() = 'head']]">
                        <fo:block text-align="justify" line-height="1.3em">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:when>
                    <xsl:otherwise>
                        <fo:block text-align="justify" text-indent="3mm" line-height="1.3em">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- - - - - - - - - - - TEXTHERVORHEBUNGEN - - - - - - - - - - -->
    <xsl:template match="tei:hi">
        <xsl:choose>
            <xsl:when test="@rend = 'bold'">
                <fo:inline font-weight="bold">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test="@rend = 'ul' or @rend = 'underline'">
                <fo:inline text-decoration="underline">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test=".[@rend = 'italic']">
                <fo:inline font-style="oblique">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test=".[@rend = 'super']">
                <fo:inline font-size="8pt" baseline-shift="super">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline font-style="oblique">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- - - - - - - - - - -    FUNKTIONEN  - - - - - - - - - - -->
    <!--Eigene Datumseresetzungsfunktion; Autor: MR-->
    <xsl:function name="my:replMonth">
        <xsl:param name="t"/>
        <xsl:value-of select="replace(replace(replace(replace(replace(replace(replace(replace($t, 'January', 'Januar'), 'February', 'Februar'), 'March', 'März'), 'May', 'Mai'), 'June', 'Juni'), 'July', 'Juli'), 'October', 'Oktober'), 'December', 'Dezember')"/>
    </xsl:function>

</xsl:stylesheet>
