<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:my="http://zeromat.org" version="2.0">


    <!--Kein Indent wegen Leerzeichen -->
    <xsl:output method="xml" version="1.0" indent="no"/>
    <xsl:preserve-space elements="*"/>

    <!-- - - - - - - - - - -    SCHRIFTARTEN    - - - - - - - - - - -->
    <xsl:variable name="ftSf" select="'AGaramondPHK-Regular'"/>
    <xsl:variable name="ftSfObl" select="'AGaramondPHK-Italic'"/>
    <xsl:variable name="ftSfBd" select="'AGaramondPHK-Bold'"/>
    <xsl:variable name="ftSFBdObl" select="'AGaramondPHK-BoldItalic'"/>

    <!-- - - - - - - - - - -    PARAMETER    - - - - - - - - - - -->
    <xsl:param name="PER" select="''"/>
    <xsl:variable name="per" select="document($PER)"/>
    <xsl:param name="SSW" select="''"/>
    <xsl:variable name="ssw" select="document($SSW)"/>
    <xsl:param name="ORT" select="''"/>
    <xsl:variable name="ort" select="document($ORT)"/>
    <xsl:param name="GQL" select="''"/>
    <xsl:variable name="gql" select="document($GQL)"/>
    <xsl:param name="UGQ" select="''"/>
    <xsl:variable name="ugq" select="document($UGQ)"/>

    <!-- - - - - - - - - - -    STATISCHE VARIABLEN - - - - - - - - - - -->
    <xsl:param name="heute">
        <xsl:value-of select="format-date(current-date(), '[D01].[M01].[Y0001]')"/>
    </xsl:param>

    <xsl:variable name="dokid" select="@xml:id"/>

    <!-- - - - - - - - - - -    BASIS   - - - - - - - - - - -->
    <xsl:template match="tei:TEI">

        <fo:root font-size="11pt" font-family="{$ftSf}" line-height="1.3em" xml:lang="de" hyphenate="true" line-height-shift-adjustment="disregard-shifts" hyphenation-push-character-count="4" hyphenation-remain-character-count="4">
            <!--Seite einrichten-->
            <fo:layout-master-set>
                <fo:simple-page-master master-name="standard-seite" page-height="297mm" page-width="210mm" margin="20mm">
                    <fo:region-body margin-top=".5in" margin-bottom="0.7in"/>
                    <fo:region-after extent=".5in" region-name="xsl-region-after"/>
                </fo:simple-page-master>
            </fo:layout-master-set>

            <fo:page-sequence master-reference="standard-seite">

                <!-- Fußzeile -->
                <fo:static-content flow-name="xsl-region-after">
                    <fo:table table-layout="fixed" width="170mm" space-before="0pt" space-after="0pt" border-top="1px solid black" color="#336699">
                        <fo:table-column column-width="30mm" text-align="left"/>
                        <fo:table-column column-width="110mm" text-align="center"/>
                        <fo:table-column column-width="30mm" text-align="end"/>
                        <fo:table-body>
                            <fo:table-row>
                                <fo:table-cell>
                                    <fo:block>
                                        <xsl:value-of select="$heute"/>
                                    </fo:block>
                                </fo:table-cell>
                                <fo:table-cell>
                                    <fo:block>
                                        <xsl:value-of select="$dokid"/>
                                    </fo:block>
                                </fo:table-cell>
                                <fo:table-cell text-align="end">
                                    <fo:block>
                                        <fo:page-number/>
                                    </fo:block>
                                </fo:table-cell>
                            </fo:table-row>
                        </fo:table-body>
                    </fo:table>
                </fo:static-content>


                <!--Hauptteil-->
                <fo:flow flow-name="xsl-region-body">

                    <!--Titelzeile-->
                    <fo:block font-family="{$ftSfBd}" font-size="14pt" font-weight="bold" space-after="15pt" text-align="center" keep-with-next="1">
                        <xsl:text>Registerdatenbank Ministerratsprotokolle 1945-1962</xsl:text>
                    </fo:block>

                    <fo:block font-family="{$ftSfBd}" font-size="14pt" font-weight="bold" space-after="15pt" text-align="center" keep-with-next="1">
                        <xsl:value-of select="//tei:teiHeader//tei:title[@type = 'Registername']"/>
                    </fo:block>
                    <xsl:apply-templates select="./tei:text"/>

                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>

    <!-- - - - - - - - - - - ROHREGISTER  - - - - - - - - - - -->
    <xsl:template match="tei:list">
        <fo:block>
            <xsl:apply-templates select=".//tei:term"/>
        </fo:block>
    </xsl:template>




    <!-- - - - - - - - - - -   ABSATZ  - - - - - - - - - - -->
    <xsl:template match="tei:p">

        <!--Spezielle Ausrichtung -->
        <xsl:choose>
            <xsl:when test=".[@rend]">
                <xsl:choose>
                    <xsl:when test="./@rend = 'head'">
                        <fo:block font-family="{$ftSfBd}" font-size="14pt" text-align="center" margin-top="2em" margin-bottom="1em" text-decoration="underline">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:when>
                    <xsl:when test="./@rend = 'vortext'">
                        <fo:block font-family="{$ftSf}" font-size="10pt" text-align="justify" margin-bottom="1em">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:when>


                    <xsl:otherwise>
                        <fo:block text-align="justify" line-height="1.3em">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>

            <!-- ...oder normaler Blocksatz mit Einzug -->
            <xsl:otherwise>

                <!--Einzug außer beim ersten Absatz eine Tagesordnungspunktes-->
                <xsl:choose>
                    <xsl:when test=".[parent::tei:div[@type = 'Top'] and preceding-sibling::*[1][local-name() = 'head']]">
                        <fo:block text-align="justify" line-height="1.3em">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:when>
                    <xsl:otherwise>
                        <fo:block text-align="justify" text-indent="3mm" line-height="1.3em">
                            <xsl:apply-templates/>
                        </fo:block>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- - - - - - - - - - - TEXTHERVORHEBUNGEN - - - - - - - - - - -->
    <xsl:template match="tei:hi">
        <xsl:choose>
            <xsl:when test="@rend = 'bold'">
                <fo:inline font-weight="bold">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test="@rend = 'ul' or @rend = 'underline'">
                <fo:inline text-decoration="underline">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test=".[@rend = 'italic']">
                <fo:inline font-style="oblique">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:when test=".[@rend = 'super']">
                <fo:inline font-size="8pt" baseline-shift="super">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline font-style="oblique">
                    <xsl:apply-templates/>
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- - - - - - - - - - -    FUNKTIONEN  - - - - - - - - - - -->
    <!--Eigene Datumseresetzungsfunktion; Autor: MR-->
    <xsl:function name="my:replMonth">
        <xsl:param name="t"/>
        <xsl:value-of select="replace(replace(replace(replace(replace(replace(replace(replace($t, 'January', 'Januar'), 'February', 'Februar'), 'March', 'März'), 'May', 'Mai'), 'June', 'Juni'), 'July', 'Juli'), 'October', 'Oktober'), 'December', 'Dezember')"/>
    </xsl:function>

</xsl:stylesheet>
